
/*
  Natjecanje timova studenata informaticara hrvatskih sveucilista 2005
  Prvo natjecanje - Zadatak MEMORIJA

  Opis algoritma:
  Zadatak rjesavamo na sljedeci nacin: Stanje memorije u svakom trenutku mozemo 
  zamisliti kao niz intervala, gdje svaki interval predstavlja uzastopne 
  memorijske lokacije koje su ili sve slobodne ili sve zauzete. Svi intervali 
  su maksimalni, odnosni svaka dva susjedna intervala su uvijek razlicite boje.
  Naredba tipa 1 ili 2 brise i dodaje nekoliko intervala. Razlikujemo 4 slucaja: 
  1. novi interval razbija neki trenutni intervala na tri dijela, 2. novi 
  interval se spaja sa prethodim intervalom, 3. novi interval se spaja sa 
  sljedecim intervalom, 4. novi interval se spaja i sa prethodnim i sa sljedecim 
  intervalom. U svakom ova 4 slucaja pobrisat cemo najvise tri intervala i 
  dodati najvise tri nova intervala.
  Da bi rjesenje bilo dovoljno efikasno potrebno je koristiti strukturu podataka 
  koja omogucuje (1) brzo trazenje intervala koji sadrzi zadani element, (2) 
  brzo brisanje intervala, (3) brzo dodavanje intervala, (4) brzo odredjivanje 
  najveceg slobodnog intervala.
  Ovo rjesenje koristi binarno stablo trazenja. Svaki cvor predstavlja jedan 
  interval i, osim pokazivaca na djecu i roditelja, sadrzi duljinu najveceg 
  slobodnog intervala u cijelom podstablu. Prilikom dodavanja i brisanja cvorova 
  ova informacija se moze efikasno odrzavati.
  Kako bi rjesenje bilo dovoljno brzo i za specijalne slucajeve kada se 
  intervali primjerice dodaju uzlazno, potrebno je stablo odrzavati 
  balansiranim. Ovdje je implementiran jednostavan pristup: kada stablo predje 
  unaprijed zadanu visinu, jednostavno se rastavi u niz i ponovo sastavi u 
  stablo tako da bude savrseno balansirano.
*/

#include <stdio.h>
#include <stdlib.h>

#define MAX(A,B) ((A)>(B)?(A):(B))
#define MAXINTERVALA 16000+2
#define MAXVISINA 50

typedef struct cvor
{
        int boja;
        int pocetak;
        int kraj;
        int najdulji;
        int visina;
        struct cvor *gore;
        struct cvor *lijevo;
        struct cvor *desno;
} cvor;

cvor *novi_cvor (int b, int p, int k)
{
        cvor *c=malloc(sizeof(cvor));
        c->boja=b;
        c->pocetak=p;
        c->kraj=k;
        c->najdulji=b==1?0:c->kraj-c->pocetak+1;
        c->visina=1;
        c->gore=NULL;
        c->lijevo=NULL;
        c->desno=NULL;
        return c;
}

cvor *dodaj (cvor *root, cvor *c)
{
        if (root==NULL) return c;
        if (c==NULL) return root;

        if (c->pocetak<=root->pocetak)
        {
                root->lijevo=dodaj(root->lijevo, c);
                root->lijevo->gore=root;
                root->najdulji=MAX(root->najdulji, root->lijevo->najdulji);
                root->visina=MAX(root->visina, root->lijevo->visina+1);
        }
        else
        {
                root->desno=dodaj(root->desno, c);
                root->desno->gore=root;
                root->najdulji=MAX(root->najdulji, root->desno->najdulji);
                root->visina=MAX(root->visina, root->desno->visina+1);
        }
        return root;
}

cvor *brisi (cvor *root, cvor *c)
{
        cvor *d=c->lijevo;
        cvor *p=c->gore;

        d=dodaj(d, c->desno);
        if (p!=NULL)
        {
                if (p->lijevo==c) p->lijevo=d;
                if (p->desno==c) p->desno=d;
        }
        else
                root=d;

        if (d!=NULL) d->gore=p;

        free(c);

        while (p!=NULL)
        {
                p->najdulji=p->boja==1?0:p->kraj-p->pocetak+1;
                p->visina=1;
                if (p->lijevo!=NULL) p->najdulji=MAX(p->najdulji, p->lijevo->najdulji);
                if (p->desno!=NULL) p->najdulji=MAX(p->najdulji, p->desno->najdulji);
                if (p->lijevo!=NULL) p->visina=MAX(p->visina, 1+p->lijevo->visina);
                if (p->desno!=NULL) p->visina=MAX(p->visina, 1+p->desno->visina);
                p=p->gore;
        }

        return root;
}

cvor *trazi (cvor *root, int x)
{
        if (x<root->pocetak) return trazi(root->lijevo, x);
        if (x>root->kraj) return trazi(root->desno, x);
        return root;
}

void brisi_sve (cvor *root)
{
        if (root==NULL) return ;
        brisi_sve(root->lijevo);
        brisi_sve(root->desno);
        free(root);
}


int n, k;
cvor *root=NULL;

int broj;
cvor *svi[MAXINTERVALA];

void bst_u_polje (cvor *root)
{
        if (root==NULL) return ;
        bst_u_polje(root->lijevo);
        svi[broj++]=root;
        bst_u_polje(root->desno);
        root->lijevo=NULL;
        root->desno=NULL;
        root->gore=NULL;
        root->visina=1;
        root->najdulji=root->boja==1?0:root->kraj-root->pocetak+1;
}

cvor *polje_u_bst (int a, int b)
{
        int c=(a+b)/2;
        if (b<a) return NULL;
        svi[c]=dodaj(svi[c], polje_u_bst(a, c-1));
        svi[c]=dodaj(svi[c], polje_u_bst(c+1, b));
        return svi[c];
}

void popravi (void)
{
        broj=0;
        bst_u_polje(root);
        root=polje_u_bst(0, broj-1);
}

void novi_interval (int a, int b, int c)
{
        cvor *p=trazi(root, a);
        cvor *p0=NULL, *p1=NULL, *p2=NULL;
        int l, r;

        if (p->pocetak<a && a+b-1<p->kraj)
        {
                p0=novi_cvor(1-c, p->pocetak, a-1);
                p1=novi_cvor(c, a, a+b-1);
                p2=novi_cvor(1-c, a+b, p->kraj);
        }
        else if (p->pocetak==a && a+b-1<p->kraj)
        {
                p1=novi_cvor(1-c, a+b, p->kraj);
                root=brisi(root, p);
                p=trazi(root, a-1);
                p0=novi_cvor(c, p->pocetak, a+b-1);
        }
        else if (p->pocetak<a && a+b-1==p->kraj)
        {
                p0=novi_cvor(1-c, p->pocetak, a-1);
                root=brisi(root, p);
                p=trazi(root, a+b);
                p1=novi_cvor(c, a, p->kraj);
        }
        else if (p->pocetak==a && a+b-1==p->kraj)
        {
                root=brisi(root, p);
                p=trazi(root, a-1);
                l=p->pocetak;
                root=brisi(root, p);
                p=trazi(root, a+b);
                r=p->kraj;
                p0=novi_cvor(c, l, r);
        }

        root=brisi(root, p);
        if (p0!=NULL) root=dodaj(root, p0);
        if (p1!=NULL) root=dodaj(root, p1);
        if (p2!=NULL) root=dodaj(root, p2);
}

int main (void)
{
        int i;
        int c, a, b;

        scanf("%d %d", &n, &k);
        root=dodaj(root, novi_cvor(1, 0, 0));
        root=dodaj(root, novi_cvor(0, 1, n));
        root=dodaj(root, novi_cvor(1, n+1, n+1));

        for (i=0; i<k; i++)
        {
                scanf("%d", &c);
                if (c==3)
                        printf("%d\n", root->najdulji);
                else
                {
                        scanf("%d %d", &a, &b);
                        novi_interval(a, b, c==1?1:0);
                        if (root->visina>MAXVISINA) popravi();
                }
        }

        brisi_sve(root);

        return 0;
}
