/*-------------------------------------------------------------*/
/* ACM ICPC 2005-2006, NEERC                                   */
/* Northern Subregional Contest                                */
/* St Petersburg, October 29, 2005                             */
/*-------------------------------------------------------------*/
/* Problem A. Astronomy                                        */
/*                                                             */
/* Original idea         Pavel Mavrin                          */
/* Problem statement     Pavel Mavrin                          */
/* Testset               Pavel Mavrin                          */
/*-------------------------------------------------------------*/
/* Model solution (Java)                                       */
/*                                                             */
/* Author                Pavel Mavrin                          */
/*-------------------------------------------------------------*/

import java.util.Scanner;
import java.io.*;
import java.math.BigInteger;

public class astronomy_pm {

    private static final int MAX_T = 10000;
    private static final int MAX_N = 1000;

    static int[] primes = new int[MAX_T];
    static int primesNumber = 0;

    static class PowersVector {
        public int[] powers;

        public PowersVector() {
            powers = new int[primesNumber];
        }

        public PowersVector(int n) {
            assert n > 0;
            powers = new int[primesNumber];
            for (int i = 0; i < primesNumber; i++) {
                while (n % primes[i] == 0) {
                    n = n / primes[i];
                    powers[i]++;
                }
            }
        }

        public PowersVector lcm(PowersVector b) {
            PowersVector result = new PowersVector();
            for (int i = 0; i < primesNumber; i++) {
                result.powers[i] = Math.max(powers[i], b.powers[i]);
            }
            return result;
        }

        public PowersVector divide(PowersVector b) {
            PowersVector result = new PowersVector();
            for (int i = 0; i < primesNumber; i++) {
                result.powers[i] = powers[i] - b.powers[i];
            }
            return result;
        }

        public String toString() {
            BigInteger n = BigInteger.ONE;
            BigInteger d = BigInteger.ONE;
            for (int i = 0; i < primesNumber; i++) {
                while (powers[i] > 0) {
                    powers[i]--;
                    n = n.multiply(BigInteger.valueOf(primes[i]));
                }
                while (powers[i] < 0) {
                    powers[i]++;
                    d = d.multiply(BigInteger.valueOf(primes[i]));
                }
            }
            return n.toString() + " " + d.toString();
        }
    }

    public static void main(String[] args) throws IOException {

        Scanner scanner = new Scanner(new File("astronomy.in"));

        int n = scanner.nextInt();

        assert n >= 2;
        assert n <= MAX_N;

        int[] t = new int[n];

        for (int i = 0; i < n; i++) {
            t[i] = scanner.nextInt();
            assert t[i] > 0;
            assert t[i] <= MAX_T;
        }

        boolean isPrime[] = new boolean[MAX_T + 1];

        for (int i = 2; i < isPrime.length; i++) {
            isPrime[i] = true;
        }

        for (int i = 2; i < isPrime.length; i++) {
            if (isPrime[i]) {
                primes[primesNumber] = i;
                primesNumber++;
                int ii = i + i;
                while (ii <= MAX_T) {
                    isPrime[ii] = false;
                    ii = ii + i;
                }                   
            }
        }

        PowersVector q = null;

        for (int i = 1; i < n; i++) if (t[i] != t[0]) {
            PowersVector pp = new PowersVector(Math.abs(2 * (t[i] - t[0])));
            PowersVector qq = new PowersVector(t[i] * t[0]);
            qq = qq.divide(pp);
            if (q == null) {
                q = qq;
            } else {
                q = q.lcm(qq);
            }
        }

        PrintWriter writer = new PrintWriter(new FileOutputStream("astronomy.out"));

        writer.write(q.toString());

        writer.close();
    }
}
