/*---------------------------------------------------------------*/
/* ACM ICPC 2005-2006, NEERC                                     */
/* Northern Subregional Contest                                  */
/* St Petersburg, October 29, 2005                               */
/*---------------------------------------------------------------*/
/* Problem H. Horn Clauses                                       */
/*                                                               */
/* Original idea         Dmitri Pavlov                           */
/* Problem statement     Dmitriy Shtukenberg                     */
/* Testset               Andrew Lopatin                          */
/*---------------------------------------------------------------*/
/* Model solution (Java)                                         */
/*                                                               */
/* Author                Georgiy Korneev                         */
/*---------------------------------------------------------------*/

import java.io.*;
import java.util.*;

class horn_gk {
    static class Var {
        List<Disjunct> inant = new ArrayList<Disjunct>();
        boolean value;
    }

    static class Disjunct {
        int antl = 0;
        Var suc;

        void process() {
            Var v = suc;
            if (v != null) {
                if (v.value) return;
                v.value = true;

                for (Disjunct d : v.inant) {
                    if (--d.antl == 0) {
                        queue.add(d);
                    }
                }
            } else {
                ok = false;
            }
        }
    }

    private static Map<String, Var> vars = new HashMap<String, Var>();
    private static LinkedList<Disjunct> queue = new LinkedList<Disjunct>();
    private static boolean ok;

    static String s;
    static int p;

    static Var parseVar() {
        StringBuilder result = new StringBuilder();
        while ('A' <= s.charAt(p) && s.charAt(p) <= 'Z') {
            result.append(s.charAt(p++));
        }
        assert(result.length() != 0);
        String v = result.toString();
        Var var = vars.get(v);
        if (var == null) {
            var = new Var();
            vars.put(v, var);
        }
        return var;
    }

    static void expect(char c) {
        assert(s.charAt(p) == c);
        p++;
    }

    static boolean test(char c) {
        if (s.charAt(p) == c) {
            p++;
            return true;
        } else {
            return false;
        }
    }

    static Disjunct parseDisjunct() {
        Disjunct d = new Disjunct();

        expect('(');
        if (!test('=')) {
            do {
                Var var = parseVar();
                var.inant.add(d);
                d.antl++;
            } while (test('&'));
            expect('=');
        } else {
            queue.add(d);
        }
        expect('>');
        if (!test(')')) {
            d.suc = parseVar();
            expect(')');
        }
        return d;
    }

    static List<Disjunct> parse() {
        p = 0;
        List<Disjunct> result = new ArrayList<Disjunct>();
        do {
            result.add(parseDisjunct());
        } while (test('&'));
        return result;
    }

    public static void main(String[] args) throws IOException {
        Locale.setDefault(Locale.US);

        BufferedReader reader = new BufferedReader(new FileReader("horn.in"));
        PrintWriter writer = new PrintWriter(new FileOutputStream("horn.out"));

        while ((s = reader.readLine()) != null) {
            s += '#';
            List<Disjunct> disjuncts = parse();

            ok = true;

            while (!queue.isEmpty()) {
                queue.removeFirst().process();
            }

            if (ok) {
                boolean f = false;
                for (Map.Entry<String, Var> var : vars.entrySet()) {
                    if (f) writer.print(", ");
                    f = true;
                    writer.print(var.getKey() + "=" + var.getValue().value);
                }
                writer.println();
            } else {
                writer.println("unsatisfiable");
            }

            vars.clear();
            queue.clear();
        }

        writer.close();
    }
}
