/*-------------------------------------------------------------*/
/* ACM ICPC 2005-2006, NEERC                                   */
/* Northern Subregional Contest                                */
/* St Petersburg, October 29, 2005                             */
/*-------------------------------------------------------------*/
/* Problem I. Inner Vertices                                   */
/*                                                             */
/* Original idea         Sergey Orshanskiy                     */
/* Problem statement     Georgiy Korneev                       */
/* Testset               Georgiy Korneev                       */
/*-------------------------------------------------------------*/
/* Model solution (Java)                                       */
/*                                                             */
/* Author                Georgiy Korneev                       */
/*-------------------------------------------------------------*/

import java.io.*;
import java.util.*;

class inner_gk implements Runnable {
    private static StreamTokenizer t;
    private static final int BASE = 131072;
    private static final int[] q = new int[2 * BASE];

    private static int nextInt() throws IOException {
        t.nextToken();
        return (int) t.nval;
    }

    private static void qsort(int l, int r, int[] a, int[] b) {
        int x = a[(l * 13 + r * 19) / 32];
        int i = l;
        int j = r;

        while (i <= j) {
            while (a[i] < x) i++;
            while (a[j] > x) j--;
            if (i <= j) {
                {int t = a[i]; a[i] = a[j]; a[j] = t;}
                {int t = b[i]; b[i] = b[j]; b[j] = t;}
                i++;
                j--;
            }
        }

        if (l < j) qsort(l, j, a, b);
        if (i < r) qsort(i, r, a, b);
    }

    private static void add(int i, int v) {
        for (i = i + BASE; i > 0; i /= 2) q[i] += v;
    }

    private static int get(int l, int r) {
        int result = 0;
        for (l = l + BASE - 1, r = r + BASE + 1; l < r - 1; l /= 2, r /= 2) {
            if ((l & 1) == 0) result += q[l + 1];
            if ((r & 1) == 1) result += q[r - 1];
        }
        return result;
    }

    public void run() {
        try {
            Locale.setDefault(Locale.US);

            t = new StreamTokenizer(new BufferedReader(new FileReader("inner.in")));
            PrintWriter writer = new PrintWriter(new FileOutputStream("inner.out"));

            int n = nextInt();
            int x[] = new int[n];
            int y[] = new int[n];
            for (int i = 0; i < n; i++) {
                x[i] = nextInt();
                y[i] = nextInt();
            }

            int[] avx = new int[n];
            int[] avy = new int[n];
            int[] aix = new int[n];
            int[] aiy = new int[n];

            for (int i = 0; i < n; i++) {
                avx[i] = x[i];
                aix[i] = i;
                avy[i] = y[i];
                aiy[i] = i;
            }

            qsort(0, n - 1, avx, aix);
            qsort(0, n - 1, avy, aiy);

            for (int i = 0, j = 0; i < n; i++) {
                if (i > 0 && avx[i - 1] < avx[i]) j++;
                x[aix[i]]= j;
            }

            for (int i = 0, j = 0; i < n; i++) {
                if (i > 0 && avy[i - 1] < avy[i]) j++;
                y[aiy[i]] = j;
            }

            int[] minv = new int[n];
            int[] minh = new int[n];
            int[] maxv = new int[n];
            int[] maxh = new int[n];

            for (int i = 0; i < n; i++) {
                minv[i] = minh[i] = n;
                maxv[i] = maxh[i] = -1;
            }

            for (int i = 0; i < n; i++) {
                minv[x[i]] = Math.min(minv[x[i]], y[i]);
                maxv[x[i]] = Math.max(maxv[x[i]], y[i]);
                minh[y[i]] = Math.min(minh[y[i]], x[i]);
                maxh[y[i]] = Math.max(maxh[y[i]], x[i]);
            }

            long c2 = 0;
            for (int i = 0; i < n; i++) {
                if (
                    (minv[x[i]] < y[i]) && (y[i] < maxv[x[i]]) && 
                    (minh[y[i]] < x[i]) && (x[i] < maxh[y[i]])
                ) c2++;
            }

            for (int i = 0; i < n; i++) {
                if (maxv[i] == minv[i]) {
                    maxv[i] = -1;
                    minv[i] = n;
                }
            }

            int[] amaxv = new int[n];
            int[] amaxi = new int[n];
            int[] aminv = new int[n];
            int[] amini = new int[n];

            for (int i = 0; i < n; i++) {
                amaxv[i] = maxv[i];
                amaxi[i] = i;
                aminv[i] = minv[i];
                amini[i] = i;
            }

            qsort(0, n - 1, amaxv, amaxi);
            qsort(0, n - 1, aminv, amini);

            long c1 = 0;

            int imin = 0;
            int imax = 0;
            while (imax < n && amaxv[imax] == -1) imax++;
            for (int i = 0; i < n; i++) {
                while (imax < n && amaxv[imax] == i) {
                    add(amaxi[imax++], -1);
                }
                c1 += get(minh[i] + 1, maxh[i] - 1);
                while (imin < n && aminv[imin] == i) {
                    add(amini[imin++], 1);
                }
            }
            writer.println(c1 + n - c2);

            writer.close();
        } catch (IOException e) {
        }
    }

    public static void main(String[] args) throws IOException {
        new Thread(new inner_gk()).start();
    }
}