/*-------------------------------------------------------------*/
/* ACM ICPC 2005-2006, NEERC                                   */
/* Northern Subregional Contest                                */
/* St Petersburg, October 29, 2005                             */
/*-------------------------------------------------------------*/
/* Problem I. Inner Vertices                                   */
/*                                                             */
/* Original idea         Sergey Orshanskiy                     */
/* Problem statement     Georgiy Korneev                       */
/* Testset               Georgiy Korneev                       */
/*-------------------------------------------------------------*/
/* Solution                                                    */
/*                                                             */
/* Author                Pavel Mavin                           */
/*-------------------------------------------------------------*/

import java.util.*;
import java.io.*;

public class inner_pm {

    static class Segment {
        public int h;
        public int l1;
        public int l2;

        public Segment(int h, int l1, int l2) {
            this.h = h;
            this.l1 = l1;
            this.l2 = l2;
        }
    }

    static class RMQ {
        private long[] a;
        private int n;

        public RMQ(int n) {
            this.n = n;
            a = new long[n];
        }

        public void add(int x) {
            while (x < n) {
                a[x]++;
                x |= x + 1;
            }
        }

        public void dec(int x) {
            while (x < n) {
                a[x]--;
                x |= x + 1;
            }
        }

        public long get(int x) {
            long result = 0;
            while (x > 0) {
                result += a[x];
                x &= x + 1;
                x--;
            }
            return result;              
        }
    }

    static Random random = new Random(11);

    static void sortX(int[] ind, int[] v, int l, int r) {
        int m = v[ind[(l + r) / 2]];
        int i = l;
        int j = r;
        while (i <= j) {
            while (v[ind[i]] < m) i++;
            while (v[ind[j]] > m) j--;
            if (i <= j) {
                int t = ind[i];
                ind[i] = ind[j];
                ind[j] = t;
                i++;
                j--;
            }
        }
        if (i < r) sortX(ind, v, i, r);
        if (l < j) sortX(ind, v, l, j);
    }
    
    static StreamTokenizer t;

    private static int nextInt() throws IOException {
        t.nextToken();
        return (int) t.nval;
    }

    public static void main(String[] args) throws IOException {
        t = new StreamTokenizer(new BufferedReader(new FileReader("inner.in")));
        int n = nextInt();

        int[] x = new int[n];
        int[] y = new int[n];

        for (int i = 0; i < n; i++) {
            x[i] = nextInt();
            y[i] = nextInt();
        }

        int[] ind = new int[n];
        for (int i = 0; i < n; i++) ind[i] = i;

        sortX(ind, x, 0, n - 1);

        List<Segment> v = new ArrayList<Segment>(n);
        Segment seg = null;

        int j = 0;
        int xx = 0;
        for (int i: ind) {
            if (j == 0 || x[i] > xx) {
                j++;
                xx = x[i];
                x[i] = j;
            } else {
                x[i] = j;
            }
        }

        for (int i: ind) {
            if (seg == null || x[i] != x[seg.h]) {
                seg = new Segment(i, i, i);
                v.add(seg);
            } else {
                if (y[i] < y[seg.l1]) seg.l1 = i;
                if (y[i] > y[seg.l2]) seg.l2 = i;
            }
        }

        sortX(ind, y, 0, n - 1);

        List<Segment> h = new ArrayList<Segment>(n);
        seg = null;

        j = 0;
        xx = 0;
        for (int i : ind) {
            if (j == 0 || y[i] > xx) {
                j++;
                xx = y[i];
                y[i] = j;
            } else {
                y[i] = j;
            }
        }

        for (int i: ind) {
            if (seg == null || y[i] != y[seg.h]) {
                seg = new Segment(i, i, i);
                h.add(seg);
            } else {
                if (x[i] < x[seg.l1]) seg.l1 = i;
                if (x[i] > x[seg.l2]) seg.l2 = i;
            }
        }

        RMQ rmq = new RMQ(v.size() + 1);

        int[] yy = new int[v.size() * 2 + h.size()];
        int[] xx1 = new int[v.size() * 2 + h.size()];
        int[] t = new int[v.size() * 2 + h.size()];
        int[] xx2 = new int[v.size() * 2 + h.size()];
        ind = new int[v.size() * 2 + h.size()];

        for (int i = 0; i < yy.length; i++) ind[i] = i;

        int ii = 0;
        for (Segment ss: v) {
            yy[ii] = y[ss.l1] * 2 - 1;
            t[ii] = 1;
            xx1[ii] = x[ss.h];
            ii++;
            yy[ii] = y[ss.l2] * 2 + 1;
            t[ii] = 2;
            xx1[ii] = x[ss.h];
            ii++;
        }

        for (Segment ss: h) {
            yy[ii] = y[ss.h] * 2;
            t[ii] = 3;
            xx1[ii] = x[ss.l1];
            xx2[ii] = x[ss.l2];
            ii++;
        }


        sortX(ind, yy, 0, ind.length - 1);

        long m = 0;

        for (int i: ind) {
            switch (t[i]) {
                case 1:
                    rmq.add(xx1[i]);
                    break;
                case 2: 
                    rmq.dec(xx1[i]);
                    break;
                case 3: 
                    m += rmq.get(xx2[i]) - rmq.get(xx1[i] - 1);
                    break;
            }
        }

        PrintWriter w = new PrintWriter(new FileOutputStream("inner.out"));
        w.print(m);
        w.close();

    }
}