/*---------------------------------------------------------------*/
/* ACM ICPC 2005-2006, NEERC                                     */
/* Northern Subregional Contest                                  */
/* St Petersburg, October 29, 2005                               */
/*---------------------------------------------------------------*/
/* Problem J. Jenny's First Exams                                */
/*                                                               */
/* Original idea         Pavel Mavrin                            */
/* Problem statement     Pavel Mavrin                            */
/* Testset               Pavel Mavrin                            */
/*---------------------------------------------------------------*/
/* Model solution (Java)                                         */
/*                                                               */
/* Author                Georgiy Korneev                         */
/*---------------------------------------------------------------*/

import java.io.*;
import java.math.*;
import java.util.*;
import java.text.*;

class jenny_gk {
    private final static SimpleDateFormat FORMAT = new SimpleDateFormat("dd.MM.yyyy");
    private final static double ZERO = parse("01.01.1900").getTime();

    private final static Date parse(String date) {
        try {            
            return FORMAT.parse(date);
        } catch (ParseException e) {
            throw new RuntimeException();
        }
    }

    private final static int getDay(String date) {
        return (int) Math.round((parse(date).getTime() - ZERO) / 1000 / 60 / 60 / 24);
    }   

    private final static String getDate(int day) {
        return FORMAT.format(new Date(Math.round(ZERO + (day + 0.5) * 1000 * 60 * 60 * 24)));
    }

    private static class Exam {
        String caption;
        int day;
        int dl;
    }

    public static void main(String[] args) throws IOException {
        Locale.setDefault(Locale.US);

        BufferedReader reader = new BufferedReader(new FileReader(new File("jenny.in")));
        PrintWriter writer = new PrintWriter(new FileOutputStream("jenny.out"));

        int n = Integer.parseInt(reader.readLine());

        Exam[] exams = new Exam[n];
        for (int i = 0; i < n; i++) {
            exams[i] = new Exam();

            exams[i].caption = reader.readLine();
            exams[i].day = getDay(reader.readLine());
            exams[i].dl = exams[i].day - Integer.parseInt(reader.readLine());
        }

        Queue<Exam> begin = new PriorityQueue<Exam>(n, new Comparator<Exam>() {
            public int compare(Exam e1, Exam e2) {
                return e2.dl - e1.dl;
            }
        });

        Queue<Exam> end = new PriorityQueue<Exam>(n, new Comparator<Exam>() {
            public int compare(Exam e1, Exam e2) {
                return e2.day - e1.day;
            }
        });

        end.addAll(Arrays.asList(exams));

        LinkedList<Exam> e = new LinkedList<Exam>();
        boolean ok = true;
        int day;
        for (day = getDay("31.12.2100"); !end.isEmpty() || !begin.isEmpty(); day--) {
            if (!end.isEmpty() && end.peek().day == day) {
                begin.offer(end.poll());
            } else if (!begin.isEmpty()) {
                Exam exam = begin.poll();

                if (exam.dl > day) {
                    ok = false;
                    break;
                }
                e.addFirst(exam);
            }
        }

        if (ok) {
            writer.println(getDate(day - begin.size() + 1));
        } else {
            writer.println("Impossible");
        }

        writer.close();
    }
}