#include <stdio.h>
#include <vector>
#include <math.h>

using namespace std;

#define SQR(x) ((x)*(x))

template<class X> X min4(X a,X b,X c,X d) {
  X x = min(a,b);
  X y = min(c,d);
  return ((x<y)?x:y);
}

struct Glass {
  int X0, Y0, X1, Y1, X2, Y2;
  int SC;
  bool Rev;
};

int N;
typedef vector<Glass> GlassData;
typedef vector<int> SortedData;
typedef vector<int> DualData;

GlassData gd;
SortedData sd;
DualData dd;

template<class X> void Swap(X& a, X& b) {
  X t = a;
  a = b;
  b = t;
}

void FailExit(const char* lpszMsg = "") {
  FILE* f=fopen("glass.out", "w");
  fprintf(f, "NO%s\n", lpszMsg);
  fclose(f);
}

void RevGlass(Glass& g) {
  g.Rev = !g.Rev;
  Swap(g.X1, g.X2);
  Swap(g.Y1, g.Y2);
}

bool MustRev(double t1, double t2) {
  if(((t1<0) && (t2<0)) || ((t1>0) && (t2>0)))
    return (t2<t1);
  if((t1<0) && (t2>0))
    return (t2-t1>3.1415927);
  return (t1-t2<3.1415927);
}

void ScrollGlass(Glass& g) {
  if(g.Rev) {
    RevGlass(g);
  }
  Swap(g.X0, g.X1);
  Swap(g.X1, g.X2);
  Swap(g.Y0, g.Y1);
  Swap(g.Y1, g.Y2);
  double t1 = atan2(g.Y1-g.Y0,g.X1-g.X0);
  double t2 = atan2(g.Y2-g.Y0,g.X2-g.X0);
  if(MustRev(t1,t2)) {
    RevGlass(g);
  }
  g.SC++;
}

void ScrollGlassNext(Glass& g) {
  ScrollGlass(g);
  while((g.X1 != g.X2) && (g.Y1 != g.Y2))
    ScrollGlass(g);
}

void MoveGlass(Glass& g, int nX0, int nY0) {
  int DX = nX0-g.X0;
  int DY = nY0-g.Y0;
  g.X1 += DX;
  g.X2 += DX;
  g.Y1 += DY;
  g.Y2 += DY;
  g.X0 = nX0;
  g.Y0 = nY0;
}

int SortGlasses(const void* a, const void* b) {
  int n1 = *(int*)a;
  int n2 = *(int*)b;
  double t1 = atan2(gd[n1].Y1-gd[n1].Y0,gd[n1].X1-gd[n1].X0);
  double t2 = atan2(gd[n2].Y1-gd[n2].Y0,gd[n2].X1-gd[n2].X0);
  return ((t1 < t2)?-1:((t1 == t2)?0:1));
}

int main() {
  FILE* fIn = fopen("glass.in", "r");
  fscanf(fIn, "%d", &N);
  int i;
  gd.resize(N);
  sd.resize(N);
  bool bFail = false;
  for(i=0; i<N; i++) {
    Glass g;
    fscanf(fIn, "%d %d %d %d %d %d", &g.X0, &g.Y0, &g.X1, &g.Y1, &g.X2, &g.Y2);
    g.SC = 0;
    g.Rev = false;
    double t1 = atan2(g.Y1-g.Y0,g.X1-g.X0);
    double t2 = atan2(g.Y2-g.Y0,g.X2-g.X0);
    if(MustRev(t1,t2)) {
      RevGlass(g);
    }
    if((g.X0 != g.X1) && (g.X0 != g.X2) && (g.X1 != g.X2) && (g.Y0 != g.Y1) && (g.Y0 != g.Y2) && (g.Y1 != g.Y2)) {
      bFail = true;
      break;
    }
    gd[i] = g;
  }
  fclose(fIn);
  if(bFail) {
    FailExit("");
    return 0;
  }
  for(i=0; i<N; i++) {
    while((gd[i].X1 != gd[i].X2) && (gd[i].Y1 != gd[i].Y2))
      ScrollGlass(gd[i]);
    if((gd[i].X0 == gd[i].X1) || (gd[i].X0 == gd[i].X2) || (gd[i].Y0 == gd[i].Y1) || (gd[i].Y0 == gd[i].Y2))
      dd.push_back(i);
  }
  int SDD = 0;
  int tmp=(1 << dd.size());
  while(SDD < tmp) {
    for(i=0; i<N; i++)
      sd[i] = i;
    qsort(&sd[0], N, sizeof(int), SortGlasses);
    bFail = false;
    for(i=1; i<N; i++) {
      if(!((gd[sd[i]].X1-gd[sd[i]].X0==gd[sd[i-1]].X2-gd[sd[i-1]].X0) && (gd[sd[i]].Y1-gd[sd[i]].Y0==gd[sd[i-1]].Y2-gd[sd[i-1]].Y0))) {
	bFail = true;
	break;
      } else
	MoveGlass(gd[sd[i]], gd[sd[i-1]].X0, gd[sd[i-1]].Y0);
    }
    if(!bFail)
      break; // all done
    int ScrollMask = (SDD ^ (SDD+1));
    int j=0;
    while((ScrollMask != 0) && (j<dd.size())) {
      if((ScrollMask & 1) == 1)
	ScrollGlassNext(gd[dd[j]]);
      ScrollMask >>= 1;
      j++;
    }
    SDD++;
  }
  if(bFail) {
    FailExit(/*": can not move glasses"*/);
//    FILE* fOut = fopen("glass.out", "a+");
//    for(i=0; i<N; i++) {
//      double t1 = atan2(gd[sd[i]].Y1-gd[sd[i]].Y0,gd[sd[i]].X1-gd[sd[i]].X0);
//      double t2 = atan2(gd[sd[i]].Y2-gd[sd[i]].Y0,gd[sd[i]].X2-gd[sd[i]].X0);
//      fprintf(fOut, "%d (%lf, %lf) - %d\n", sd[i], t1, t2, MustRev(t1,t2)?1:0);
//    }
//    fclose(fOut);
  } else {
    FILE* fOut = fopen("glass.out", "w");
    for(i=0; i<N; i++) {
      while(gd[i].SC%3!=0)
	ScrollGlass(gd[i]);
      if(gd[i].Rev)
	RevGlass(gd[i]);
      int DX = 0x7fffffff;
      int DY = 0x7fffffff;
      for(int j=0; j<N; j++) {
	DX = min4(DX, gd[j].X0, gd[j].X1, gd[j].X2);
	DY = min4(DY, gd[j].Y0, gd[j].Y1, gd[j].Y2);
      }
      fprintf(fOut, "%d %d %d %d %d %d\n", gd[i].X0-DX, gd[i].Y0-DY, gd[i].X1-DX, gd[i].Y1-DY, gd[i].X2-DX, gd[i].Y2-DY);
    }
    fclose(fOut);
  }
  return 0;
}
