{$A+,B-,D+,E+,F-,G+,I+,L+,N+,O-,P-,Q-,R-,S+,T-,V+,X+,Y+}
{$M 65520,0,655360}
program         Template;

type
  Tristate      = (tsUnknown, tsTrue, tsFalse, tsMixed);
  PEdge         = ^TEdge;
  TEdge         = record
    V           : Integer;
    Next        : PEdge;
  end;

var
  N             : Integer;
  X, Y          : array[1..2000, 1..3] of Integer;
  Center        : array[1..2000] of 1..3;
  DX, DY        : array[1..2000] of Integer;
  EX, EY        : array[1..2000] of Integer;
  Horizontal    : array[1..2000] of Tristate;
  Edges         : array[1..2000] of PEdge;
  Visited       : array[1..2000] of Boolean;
  Sequence      : array[1..2000] of Integer;
  XMin, YMin    : Integer;

procedure       OpenFiles;
begin
  Assign(Input, 'glass.in');
  Reset(Input);
  Assign(Output, 'glass.out');
  Rewrite(Output);
end;

procedure       CloseFiles;
begin
  Close(Input);
  Close(Output);
end;

procedure       ReadData;
var
  I, J          : Integer;
begin
  ReadLn(N);
  for I := 1 to N do
    for J := 1 to 3 do
      Read(X[I, J], Y[I, J]);
end;

function        Min(A, B: Integer): Integer;
begin
  if A < B then
    Min := A
  else
    Min := B;
end;

function        Max(A, B: Integer): Integer;
begin
  if A > B then
    Max := A
  else
    Max := B;
end;

procedure       BuildCase(K, A, B, C: Integer);
begin
  if Horizontal[K] = tsMixed then
    Exit;

  if X[K, A] = X[K, B] then begin
    if Y[K, A] = Y[K, C] then begin
      Horizontal[K] := tsMixed;
      DX[K] := X[K, C] - X[K, A];
      DY[K] := Y[K, B] - Y[K, A];

      Center[K] := A;
    end else begin
      Horizontal[K] := tsFalse;
      DX[K] := X[K, C] - X[K, A];
      DY[K] := Y[K, C] - Min(Y[K, A], Y[K, B]);
      EX[K] := X[K, C] - X[K, A];
      EY[K] := Y[K, C] - Max(Y[K, A], Y[K, B]);

      Center[K] := C;
    end;
  end else if Y[K, A] = Y[K, B] then begin
    if X[K, A] = X[K, C] then begin
      Horizontal[K] := tsMixed;
      DX[K] := X[K, B] - X[K, A];
      DY[K] := Y[K, C] - Y[K, A];

      Center[K] := A;
    end else begin
      Horizontal[K] := tsTrue;
      DX[K] := X[K, C] - Min(X[K, A], X[K, B]);
      DY[K] := Y[K, C] - Y[K, A];
      EX[K] := X[K, C] - Max(X[K, A], X[K, B]);
      EY[K] := Y[K, C] - Y[K, A];

      Center[K] := C;
    end;
  end;
end;

procedure       BuildTables;
var
  I, J, K       : Integer;
begin
  FillChar(Horizontal, SizeOf(Horizontal), tsUnknown);
  for I := 1 to N do begin
    BuildCase(I, 1, 2, 3);
    BuildCase(I, 1, 3, 2);
    BuildCase(I, 2, 1, 3);
    BuildCase(I, 2, 3, 1);
    BuildCase(I, 3, 1, 2);
    BuildCase(I, 3, 2, 1);
  end;
end;

procedure       AddEdge(V, U: Integer);
var
  Edge          : PEdge;
begin
  New(Edge);
  Edge^.V := U;
  Edge^.Next := Edges[V];
  Edges[V] := Edge;
end;

function        CanConnectMixed(A, B: Integer; First: Boolean): Boolean;
var
  Result        : Boolean;
begin
  if Horizontal[B] = tsMixed then begin
    Result := (LongInt(DX[A]) * LongInt(DX[B]) < 0) and (DY[A] = DY[B]);
    Result := Result or (LongInt(DY[A]) * LongInt(DY[B]) < 0) and (DX[A] = DX[B]);
  end else begin
    Result := (DX[A] = -EX[B]) and (DY[A] = -EY[B]);
    Result := Result or ((DX[A] = -DX[B]) and (DY[A] = -DY[B]));
  end;

  CanConnectMixed := Result;
end;

function        CanConnect(A, B: Integer; First: Boolean): Boolean;
var
  Result        : Boolean;
begin
  if Horizontal[A] = tsMixed then begin
    CanConnect := CanConnectMixed(A, B, First);
    Exit;
  end;

  Result := (DX[A] = EX[B]) and (DY[A] = EY[B]);
  Result := Result or ((DX[A] = DX[B]) and (DY[A] = DY[B]));
  Result := Result or ((EX[A] = DX[B]) and (DY[A] = EY[B]));

  if not First then
    CanConnect := Result
  else
    CanConnect := Result or CanConnect(B, A, False);
end;

procedure       BuildEdges;
var
  I, J          : Integer;
begin
  FillChar(Edges, SizeOf(Edges), 0);
  for I := 1 to N do
    for J := 1 to N do
      if I <> J then
        if CanConnect(I, J, True) then
          AddEdge(I, J);
end;

function        DFS(V, T: Integer): Boolean;
var
  E             : PEdge;
begin
  if T >= N then begin
    DFS := False;
    Exit;
  end;

  Visited[V] := True; E := Edges[V]; DFS := False;
  while E <> nil do begin
    if (E^.V = 1) and (T = N - 1) then begin
      Sequence[T + 1] := V;

      DFS := True;
      Exit;
    end;
    if not Visited[E^.V] then
      if DFS(E^.V, T + 1) then begin
        Sequence[T + 1] := V;

        DFS := True;
        Exit;
      end;

    E := E^.Next;
  end;
  Visited[V] := False;
end;

function        Search: Boolean;
begin
  FillChar(Visited, SizeOf(Visited), 0);

  Search := DFS(1, 0);
end;

procedure       Shift(K, BX, BY: Integer);
var
  DX, DY        : Integer;
begin
  DX := BX - X[K, Center[K]];
  DY := BY - Y[K, Center[K]];

  Inc(X[K, 1], DX); Inc(Y[K, 1], DY);
  Inc(X[K, 2], DX); Inc(Y[K, 2], DY);
  Inc(X[K, 3], DX); Inc(Y[K, 3], DY);
end;

procedure       ShiftMixed(K, Q, BX, BY: Integer; Hor: Boolean);
var
  AX, AY        : Integer;
  CX, CY        : Integer;
begin
  if Horizontal[Q] = tsMixed then begin
    if DY[K] = DY[Q] then begin
      AX := BX - X[K, Center[K]] - DX[K];
      AY := BY - Y[K, Center[K]];
    end else begin
      AX := BX - X[K, Center[K]];
      AY := BY - Y[K, Center[K]] - DY[K];
    end;
  end else begin
    Shift(Q, BX, BY);
{
    if (DX[K] = -EX[Q]) and (DY[K] = -EY[Q]) then begin
      CX := X[K, Center[K]];
      CY := Y[K, Center[K]] + DY[K];
    end;

    if ((DX[K] = -DX[Q]) and (DY[K] = -DY[Q])) then begin
      CX := X[K, Center[K]] + DX[K];
      CY := Y[K, Center[K]];
    end;
}
    if Hor then begin
      CX := X[K, Center[K]];
      CY := Y[K, Center[K]] + DY[K];
    end else begin
      CX := X[K, Center[K]] + DX[K];
      CY := Y[K, Center[K]];
    end;

    AX := BX - CX;
    AY := BY - CY;
  end;

  Inc(X[K, 1], AX); Inc(Y[K, 1], AY);
  Inc(X[K, 2], AX); Inc(Y[K, 2], AY);
  Inc(X[K, 3], AX); Inc(Y[K, 3], AY);
end;

function        CanBe(A, B: Tristate): Boolean;
begin
  if A = tsMixed then
    CanBe := True
  else
    CanBe := A = B;
end;

function        Check1(K: Integer): Boolean;
begin
  if Horizontal[K] <> tsMixed then
    Check1 := DY[Sequence[K]] > 0
  else
    Check1 := DY[Sequence[K]] < 0;
end;

function        Check2(K: Integer): Boolean;
begin
  if Horizontal[K] <> tsMixed then
    Check2 := DX[Sequence[K]] > 0
  else
    Check2 := DX[Sequence[K]] < 0;
end;

function        MovePieces: Boolean;
var
  I, J, BI      : Integer;
  Base, BX, BY  : Integer;
  Hor           : Boolean;
begin
  Base := 0; I := 1;
  while (I <= N) and (Base = 0) do begin
    J := I + 1;
    if J > N then
      J := 1;
{
    if CanBe(Horizontal[Sequence[I]], tsFalse) and CanBe(Horizontal[Sequence[J]], tsTrue) then
      if Horizontal[Sequence[I]] <> tsMixed then begin
        if (DX[Sequence[I]] > 0) and Check1(J) then
          Base := I;
      end else begin
        if (DX[Sequence[I]] < 0) and (DY[Sequence[J]] > 0) then
          if Base = 0 then
            Base := I;
      end;

    if CanBe(Horizontal[Sequence[I]], tsTrue) and CanBe(Horizontal[Sequence[J]], tsFalse) then
      if Horizontal[Sequence[I]] <> tsMixed then begin
        if (DY[Sequence[I]] > 0) and Check2(J) then
          Base := J;
      end else begin
        if (DY[Sequence[I]] > 0) and (DX[Sequence[J]] < 0) then
          if Base = 0 then
            Base := J;
      end;
}
    if Horizontal[Sequence[I]] <> tsMixed then begin
      Base := Sequence[I];
      BI := I;
    end;

    Inc(I);
  end;

  XMin := 0; YMin := 0;
  if Base > 0 then begin
    if Horizontal[Base] <> tsMixed then begin
      BX := DX[Base];
      BY := DY[Base];
    end else begin
      BX := -DX[Base];
      BY := DY[Base];
    end;

    I := BI; J := 0;
    while (I <> BI) or (J = 0) do begin
      J := I + 1;
      if J > N then
        J := 1;

      if Horizontal[Sequence[I]] <> tsMixed then
        Hor := Horizontal[Sequence[I]] = tsTrue;

      case Horizontal[Sequence[I]] of
        tsTrue, tsFalse:
          Shift(Sequence[I], BX, BY);
        tsMixed:
          ShiftMixed(Sequence[I], Sequence[J], BX, BY, Hor);
      end;

      I := J;
    end;

(*
    for I := 1 to N do begin
      J := I + 1;
      if J > N then
        J := 1;

      case Horizontal[Sequence[I]] of
        tsTrue, tsFalse:
          Shift(Sequence[I], BX, BY);
        tsMixed:
          ShiftMixed(Sequence[I], Sequence[J], BX, BY);
      end;
    end;
*)
    for I := 1 to N do begin
      XMin := Min(XMin, X[I, 1]);
      XMin := Min(XMin, X[I, 2]);
      XMin := Min(XMin, X[I, 3]);
      YMin := Min(YMin, Y[I, 1]);
      YMin := Min(YMin, Y[I, 2]);
      YMin := Min(YMin, Y[I, 3]);
    end;
  end;

  MovePieces := Base > 0;
end;

procedure       Solve;
var
  I             : Integer;
begin
  BuildTables;
  BuildEdges;

  if not Search then
    WriteLn('NO')
  else begin
    if MovePieces then
      for I := 1 to N do begin
        Write(X[I, 1] - XMin, ' ', Y[I, 1] - YMin, ' ');
        Write(X[I, 2] - XMin, ' ', Y[I, 2] - YMin, ' ');
        WriteLn(X[I, 3] - XMin, ' ', Y[I, 3] - YMin);
      end
    else
      WriteLn('NO');
  end;
end;

begin
  OpenFiles;
  ReadData;
  Solve;
  CloseFiles;
end.