const
  inputfile = 'travel.in';
  outputfile = 'travel.out';
  maxn = 110;
  eps = 1e-5;

type
  int = integer;
  bool = boolean;
  real = double;
  tpoint = record
    x, y: real;
  end;
  tline = record
    a, b, c: real;
  end;
  tpoly = array[1..5]of tpoint;

var
  n, i, j, k, col, mx, count: int;
  t: array[1..maxn]of tpoly;
  a: array[1..maxn, 1..maxn]of byte;
  circle: bool;
  used: array[1..maxn]of bool;
  cl, cnt, f: array[1..maxn]of int;

procedure getlinebypoints(var t1, t2: tpoint; var l: tline);
begin
  l.a := t2.y - t1.y;
  l.b := t1.x - t2.x;
  l.c := t2.x * t1.y - t1.x * t2.y;
end;

function crosslines(var l1, l2: tline; var t: tpoint): bool;
var
  det: real;
begin
  det := l1.a * l2.b - l2.a * l1.b;
  if(abs(det) > eps)then begin
    crosslines :=  true;
    t.x := -(l1.c * l2.b - l2.c * l1.b) / det;
    t.y := -(l1.a * l2.c - l2.a * l1.c) / det;
  end else
    crosslines := false;
end;

function square(var p: tpoly): real;
var
  i: int;
  s: real;
begin
  s := 0.0;
  for i := 1 to 3 do
    s := s + p[i].x * p[i + 1].y - p[i + 1].x * p[i].y;
  square := abs(s) / 2.0;
end;

function pointinpoly(t: tpoint; var p: tpoly): bool;
var
  tr: tpoly;
  i: int;
  s: real;
begin
  tr[1] := t;
  tr[4] := t;
  s := square(p);

  for i := 1 to 3 do begin
    tr[2] := p[i];
    tr[3] := p[i + 1];
    s := s - square(tr);
  end;
  pointinpoly := abs(s) < eps;
end;

function pointinotr(t, b, e: tpoint): bool;
begin
  pointinotr := false;
  if(t.x + eps > b.x)and(t.x - eps < e.x)or(t.x + eps > e.x)and(t.x - eps < b.x)then
    if(t.y + eps > b.y)and(t.y - eps < e.y)or(t.y + eps > e.y)and(t.y - eps < b.y)then
      pointinotr := true;
end;

function segmcross(var a1, a2, b1, b2: tpoint): bool;
var
  l1, l2: tline;
  t: tpoint;
begin
  segmcross := false;
   getlinebypoints(a1, a2, l1);
   getlinebypoints(b1, b2, l2);
   if(crosslines(l1, l2, t))then
     if(pointinotr(t, a1, a2))then
       if(pointinotr(t, b1, b2))then
         segmcross := true;
end;

function onepointinside(a, b: tpoly): bool;
var
  i, j, count: int;
  ok: bool;
begin
  count := 0;
  onepointinside := false;
  for i := 1 to 3 do begin
    if(pointinpoly(b[i], a))then begin
      for j := 1 to 3 do begin
        ok := false;
        if(segmcross(b[i], b[i + 1], a[j], a[j + 1]))then
          if(segmcross(b[i], b[i + 2], a[j], a[j + 1]))then
            ok := true;
        if(ok)then
          inc(count);
      end;
    end;
  end;
  onepointinside := count = 1;
end;

function max(a, b: int): int;
begin
  if(a > b)then
    max := a
  else
    max := b;
end;

function dfs(v: int): int;
var
  i: int;
begin
  used[v] := true;
  cl[v] := col;
  for i := 1 to n do begin
    if(a[v, i] = 0)then
      continue;
    if(not used[i])then
      cnt[v] := max(cnt[v], dfs(i) + 1);
  end;
  dfs := cnt[v];
end;

procedure tpsort(v: int);
var
  i: int;
begin
  used[v] := true;
  for i := 1 to n do begin
    if(a[v, i] = 0)then
      continue;
    if(not used[i])then
      tpsort(i);
  end;
  inc(count);
  f[v] := count;
end;

procedure check;
var
  i, j: int;
begin
  for i := 1 to n do begin
    for j := 1 to n do
      if(a[i, j] > 0)and(f[i] < f[j])then begin
        circle := true;
        exit;
      end;
  end;
end;

begin
  assign(input, inputfile);
  reset(input);
  assign(output, outputfile);
  rewrite(output);
  read(n);
  for i := 1 to n do begin
    for j := 1 to 3 do
      read(t[i, j].x, t[i, j].y);
    t[i, 4] := t[i, 1];
    t[i, 5] := t[i, 2];
  end;

  for i := 1 to n do
    for j := 1 to n do
      if(i <> j)then
        if(onepointinside(t[i], t[j]))then
          a[i, j] := 1;

  for i := 1 to n do
    if(not used[i])then
      tpsort(i);
  check;


  fillchar(used, sizeof(used), 0);
  for i := n downto 1 do
    if(not used[f[i]])then begin
      inc(col);
      dfs(f[i]);
    end;

  mx := 0;
  for i := 1 to n do
    mx := max(cnt[i], mx);


  if(circle)then
    write(-1)
  else
    write(mx);

  close(output);
  close(input);
end.