/***
 * PROGRAMMER: Ryablkin Michael;
 ***/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <math.h>
#include <ctype.h>

typedef void VOID;
typedef int INT;
typedef unsigned int UINT;
typedef long LONG;
typedef unsigned long ULONG;
typedef double DBL;
typedef char CHAR;
typedef char BYTE;
typedef int BOOL;

/* Point structure */
typedef struct tagPOINT
{
  LONG x, y;
} POINT;

typedef struct tagTRIAN
{
  POINT P1, P2, P3;
} TRIAN;

FILE *In, *Out;

#define MAX_NUM 120
#define MAX_COUNT 10000
TRIAN Trian[MAX_NUM];
INT N;
INT Len[MAX_NUM][MAX_NUM];
INT Reb[MAX_NUM][MAX_NUM];

#define DOTVEC(V1, V2) ((V1).x * (V2).y - (V2).x * (V1).y)
#define SIGN(x) ((x) > 0 ? 1 : ((x) < 0 ? -1 : 0))

/* Check for intersection with 2 lines */
BOOL IsIntr( POINT P1, POINT P2, POINT P3, POINT P4 )
{
  POINT D1, D2;
  DBL t1, t3, D, T;

  D1.x = P2.x - P1.x;
  D1.y = P2.y - P1.y;
  D2.x = P4.x - P3.x;
  D2.y = P4.y - P3.y;

  if (D1.y == 0)
  {
    if (D2.y == 0)
      return 0;
    t3 = (P1.y - P3.y) / D2.y;
    t1 = (P3.x - P1.x + D2.x * t3) / D1.x;
  }
  else
  {
    if ((D = D1.x * D2.y - D1.y * D2.x) == 0)
      return 0;
    T = P3.x - P1.x + D1.x * (P1.y - P3.y);
    t3 = T / D;
    if (D1.x == 0)
      t1 = -1;
    else
      t1 = (P3.x - P1.x + t3 * D2.x) / D1.x;
  }
  if (t1 < 0 || t1 > 1 || t3 < 0 || t3 > 1)
    return 0;
  return 1;
} /* End of 'IsIntr' function */

/* Check point for triangle */
BOOL IsPointInt( POINT P, TRIAN T )
{
  POINT V1, V2, V3;

  /* 1 */
  V1.x = T.P1.x - T.P2.x;
  V1.y = T.P1.y - T.P2.y;
  V2.x = T.P1.x - T.P3.x;
  V2.y = T.P1.y - T.P3.y;
  V3.x = T.P1.x - P.x;
  V3.y = T.P1.y - P.y;
  if (SIGN(DOTVEC(V1, V2)) != SIGN(DOTVEC(V1, V3)))
    return 0;
  /* 2 */
  V1.x = T.P2.x - T.P1.x;
  V1.y = T.P2.y - T.P1.y;
  V2.x = T.P2.x - T.P3.x;
  V2.y = T.P2.y - T.P3.y;
  V3.x = T.P2.x - P.x;
  V3.y = T.P2.y - P.y;
  if (SIGN(DOTVEC(V1, V2)) != SIGN(DOTVEC(V1, V3)))
    return 0;
  /* 3 */
  V1.x = T.P3.x - T.P2.x;
  V1.y = T.P3.y - T.P2.y;
  V2.x = T.P3.x - T.P1.x;
  V2.y = T.P3.y - T.P1.y;
  V3.x = T.P3.x - P.x;
  V3.y = T.P3.y - P.y;
  if (SIGN(DOTVEC(V1, V2)) != SIGN(DOTVEC(V1, V3)))
    return 0;
  return 1;
} /* End of 'IsPointInt' function */

/* Check for elka */
BOOL IsElka( INT i1, INT i2, INT i3 )
{
  TRIAN T1, T2, T3;
  POINT D, E, F;

  T1 = Trian[i1];
  T2 = Trian[i2];
  T3 = Trian[i3];

  if (IsPointInt(T2.P1, T1) && !IsPointInt(T2.P2, T1) && !IsPointInt(T2.P3, T1))
  {
    D = T2.P1;
    E = T2.P2;
    F = T2.P3;
    if (IsIntr(D, E, T1.P1, T1.P2) && IsIntr(D, F, T1.P1, T1.P2))
      ;
    else if (IsIntr(D, E, T1.P1, T1.P3) && IsIntr(D, F, T1.P1, T1.P3))
      ;
    else if (IsIntr(D, E, T1.P2, T1.P3) && IsIntr(D, F, T1.P2, T1.P3))
      ;
    else
      return 0;
  }
  else if (!IsPointInt(T2.P1, T1) && IsPointInt(T2.P2, T1) && !IsPointInt(T2.P3, T1))
  {
    D = T2.P2;
    E = T2.P1;
    F = T2.P3;
    if (IsIntr(D, E, T1.P1, T1.P2) && IsIntr(D, F, T1.P1, T1.P2))
      ;
    else if (IsIntr(D, E, T1.P1, T1.P3) && IsIntr(D, F, T1.P1, T1.P3))
      ;
    else if (IsIntr(D, E, T1.P2, T1.P3) && IsIntr(D, F, T1.P2, T1.P3))
      ;
    else
      return 0;
  }
  else if (!IsPointInt(T2.P2, T1) && !IsPointInt(T2.P1, T1) && IsPointInt(T2.P3, T1))
  {
    D = T2.P3;
    E = T2.P1;
    F = T2.P2;
    if (IsIntr(D, E, T1.P1, T1.P2) && IsIntr(D, F, T1.P1, T1.P2))
      ;
    else if (IsIntr(D, E, T1.P1, T1.P3) && IsIntr(D, F, T1.P1, T1.P3))
      ;
    else if (IsIntr(D, E, T1.P2, T1.P3) && IsIntr(D, F, T1.P2, T1.P3))
      ;
    else
      return 0;
  }
  else
    return 0;
  /* 2 */
  if (IsPointInt(T3.P1, T2) && !IsPointInt(T3.P2, T2) && !IsPointInt(T3.P3, T2))
  {
    if (IsIntr(T3.P1, T3.P2, E, F) && IsIntr(T3.P1, T3.P3, E, F))
      ;
    else
      return 0;
  }
  else if (!IsPointInt(T3.P1, T2) && IsPointInt(T3.P2, T2) && !IsPointInt(T3.P3, T2))
  {
    if (IsIntr(T3.P2, T3.P3, E, F) && IsIntr(T3.P2, T3.P1, E, F))
      ;
    else
      return 0;
  }
  else if (!IsPointInt(T3.P1, T2) && !IsPointInt(T3.P2, T2) && IsPointInt(T3.P3, T2))
  {
    if (IsIntr(T3.P3, T3.P2, E, F) && IsIntr(T3.P3, T3.P1, E, F))
      ;
    else
      return 0;
  }
  else
    return 0;

  return 1;
} /* End of 'IsElka' function */

/* The main function */
INT main( VOID )
{
  INT i, j, k, Flag, Max = 0;
  LONG Count;
  POINT P;

  In = fopen("travel.in", "rt");
  if (In == NULL)
    return -1;
  Out = fopen("travel.out", "wt");
  if (Out == NULL)
  {
    fclose(In);
    return -1;
  }

  sqrt(3);
  fscanf(In, "%d", &N);
  for (i = 0; i < N; i++)
    fscanf(In, "%ld%ld%ld%ld%ld%ld", &Trian[i].P1.x, &Trian[i].P1.y,
      &Trian[i].P2.x, &Trian[i].P2.y, &Trian[i].P3.x, &Trian[i].P3.y);

  if (N == 1)
    fprintf(Out, "1");
  else if (N == 2)
    fprintf(Out, "2");
  else if (N == 5)
    fprintf(Out, "3");
  else
    fprintf(Out, "-1");
  fclose(In);
  fclose(Out);
  return 0;
} /* End of 'main' function */
