{$apptype CONSOLE}
{$R+}

const
	inFile = 'roads.in';
	outFile = 'roads.out';

	maxN = 50;
	maxM = maxN * maxN div 2;
	inf = maxint div 2;

type
	TEdge = record
		u, v, w : integer;
	end;

var
	n, m : integer;
	e : array[1..maxM] of TEdge;
	st : array[1..maxN,1..maxN] of integer;
	w : array[1..maxN,1..maxM] of integer;
	pxy : array[1..maxN] of integer;
	pyx : array[1..maxM] of integer;
    d : array[-1..maxN + maxM] of integer;

	nx, ny : integer;


procedure ReadData;
var
	i : integer;

begin
	assign(input, inFile);
	reset(input);

	fillchar(st, sizeof(st), 0);

	read(n, m);
	for i := 1 to m do begin
		read(e[i].u, e[i].v, e[i].w);
		st[e[i].u, e[i].v] := i;
		st[e[i].v, e[i].u] := i;
	end;	

	close(input);
end;

procedure WriteData;
var
    i : integer;
begin
	assign(output, outFile);
	rewrite(output);
	writeln(n, ' ', m);
    for i := 1 to m do
    	writeln(e[i].u, ' ', e[i].v, ' ', e[i].w - d[i]);
	close(output);
end;

procedure BuildGraph;
var
	i : integer;
	used : array[1..maxN] of boolean;
	stack : array[1..maxN] of integer;
	sp : integer;

	procedure DFS(ei, i, tg : integer);
	var
		j : integer;

	begin
		used[i] := true;
		if i = tg then begin
			for j := 1 to sp do
				if e[stack[j]].w > e[ei].w then
					w[stack[j], ei - nx] := e[ei].w - e[stack[j]].w;
			exit;
		end;

		for j := 1 to n do
			if not used[j] and (st[i,j] > 0) and (st[i,j] <= nx) then begin
				inc(sp);
				stack[sp] := st[i,j];
				DFS(ei, j, tg);
				dec(sp);
			end;
	end;

begin
	nx := n - 1;
	ny := m - n + 1;

	fillchar(w, sizeof(w), 0);

	for i := 1 to ny do begin
		fillchar(used, sizeof(used), false);
		sp := 0;
		DFS(i + nx, e[i + n - 1].u, e[i + n - 1].v);
	end;
end;

procedure FordBellman;
var
	i, j, k : integer;

	procedure Relax(i, j : integer; w : integer);
	begin
		if d[j] > d[i] + w then
			d[j] := d[i] + w;
	end;

begin
	for i := 0 to nx + ny do
		d[i] := inf;
	d[-1] := 0;

	for j := 1 to nx do
		Relax(-1, j, 0);
	for j := 1 to nx do
		for k := 1 to ny do
			Relax(j, k + nx, w[j,k]);
	for j := 1 to ny do
		Relax(nx + j, 0, 0);
end;

function Dijkstra : boolean;
var
	used : array[-1..maxN+maxM] of boolean;
	q : array[-1..maxN+maxM] of integer;
	parent : array[-1..maxN+maxM] of integer;
	i, j : integer;
	min : integer;

	procedure Relax(i, j : integer; w : integer);
	begin
		if q[j] > q[i] + w then begin
			q[j] := q[i] + w;
			parent[j] := i;
		end;
	end;

	function EdgeWeight(i, j : integer) : integer;
	begin
		EdgeWeight := inf;
		if (i = -1) and (j > 0) and (j <= nx) then begin
			if pxy[j] = 0 then
				EdgeWeight := 0;
		end else if (i > 0) and (i <= nx) and (j > nx) then begin
			if pxy[i] <> j - nx then
				EdgeWeight := w[i,j - nx] - (d[j] - d[i]);
		end else if (j > 0) and (j <= nx) and (i > nx) then begin
			if pyx[i - nx] = j then
				EdgeWeight := -w[j, i - nx] - (d[j] - d[i]);
		end else if (i > nx) and (j = 0) then begin
			if pyx[i - nx] = 0 then
				EdgeWeight := -(d[j] - d[i]);
		end;

        if result < 0 then asm int 3; end;
	end;

begin
	fillchar(used, sizeof(used), false);
	for i := 0 to nx + ny do
		q[i] := inf;
	q[-1] := 0;
    for i := -1 to nx + ny do
        parent[i] := -2;
	while true do begin
		min := inf;
		j := 0;
		for i := -1 to nx + ny do
			if not used[i] and (q[i] < min) then begin
				min := q[i];
				j := i;
			end;

		if min = inf then
			break;

		used[j] := true;
		for i := -1 to nx + ny do
			Relax(j, i, EdgeWeight(j, i));
	end;

	if not used[0] then begin
		Dijkstra := false;
		exit;
	end;

	for i := -1 to nx + ny do
		inc(d[i], q[i]);

	i := parent[0];
	while i <> -1 do begin
		j := parent[i];
		pxy[j] := i - nx;
		pyx[i - nx] := j;
		i := parent[j];
	end;

	Dijkstra := true;
end;

procedure Solve;
var
	i : integer;

begin
	BuildGraph;
	FordBellman;

	fillchar(pxy, sizeof(pxy), 0);
	fillchar(pyx, sizeof(pyx), 0);
	for i := 1 to nx do
		if not Dijkstra then
			break;
end;

begin
	ReadData;
	Solve;
	WriteData;
end.
