#include <stdio.h>
#include <string.h>

FILE*fi,*fo;

#define INF ((long)0x7FFFFF00)

struct TPoint {
  long x,y;
};
struct TEdge {
  int v,w;
};
struct TVertice {
  int u;
  TVertice*z;
};

class TGraph {
  private:
    int n,e,c;
    long N,m;
    TVertice*A,**a,**b;
    TPoint*d;
    char*G,**g;
    long*dd; TEdge*de;
    TEdge*o;
    int*h,*q;
    long dist(int,int);
    void search(int);
  public:
    TGraph(void);
    ~TGraph();
    void Delete(void);
    void scan(FILE*);
    void print(FILE*);
    void observe(void);
    void process(void);
};

TGraph g;

int main(void) {
  fi=fopen("road.in","rt");
  g.scan(fi);
  fclose(fi);
  g.observe();
  g.process();
  fo=fopen("road.out","wt");
  g.print(fo);
  fclose(fo);
  return(0);
}


void TGraph::search(int u) {
  int i,l,v,w;
  q[0]=u; h[u]=e; l=1;
  for (i=0; i<l; i++) {
    v=q[i];
    for (w=0; w<n; w++) if ((h[w]<0)&&(g[v][w])) {
      q[l]=w; h[w]=e; l++;
    }
  }
}
void TGraph::observe(void) {
  int i,j;
  memset(h,-1,n*sizeof(int)); e=0;
  for (i=0; i<n; i++) if (h[i]<0) { search(i); e++; }
  for (i=0; i<n; i++) { A[i].u=i; A[i].z=0; }
  for (j=0; j<e; j++) b[j]=a[j]=0;
  for (i=0; i<n; i++) {
    j=h[i];
    if (a[j]) {
      b[j]->z=&A[i];
      b[j]=&A[i];
    } else b[j]=a[j]=&A[i];
  }
}

void TGraph::process(void) {
  int k,i,j,v,w;
  TVertice*x,*y;
  long d0,d1; TEdge e0;
  for (j=1; j<e; j++) {
    d0=INF;
    for (x=a[0]; x; x=x->z) for (y=a[j]; y; y=y->z) {
      d1=dist(x->u,y->u);
      if (d0>d1) { d0=d1; e0.v=x->u; e0.w=y->u; }
    }
    dd[j]=d0; de[j]=e0;
  }
  c=0;
  for (k=1; k<e; k++) {
    d0=INF; i=-1;
    for (j=1; j<e; j++) if (d0>dd[j]) { i=j; d0=dd[j]; }
    o[c++]=de[i];
    for (j=1; j<e; j++) if (j!=i) {
      d0=INF;
      for (x=a[i]; x; x=x->z) for (y=a[j]; y; y=y->z) {
        d1=dist(x->u,y->u);
        if (d0>d1) { d0=d1; e0.v=x->u; e0.w=y->u; }
      }
      if (dd[j]>d0) { dd[j]=d0; de[j]=e0; }
    }
    b[0]->z=a[i]; b[0]=b[i]; b[i]=a[i]=0; dd[i]=INF;
  }
}

TGraph::TGraph(void) {
  A=0; a=0; b=0;
  d=0;
  G=0; g=0;
  dd=0; de=0;
  o=0;
  h=0; q=0;
}
TGraph::~TGraph() {
  Delete();
}
void TGraph::Delete(void) {
  if (A) delete[]A; if (a) delete[]a; if (b) delete[]b;
  if (d) delete[]d;
  if (G) delete[]G; if (g) delete[]g;
  if (dd) delete[]dd; if (de) delete[]de;
  if (o) delete[]o;
  if (h) delete[]h; if (q) delete[]q;
}
void TGraph::scan(FILE*f) {
  Delete();
  int i,j; long l;
  fscanf(f,"%d%ld",&n,&m);
  A=new TVertice[n]; a=new TVertice*[n]; b=new TVertice*[n];
  d=new TPoint[n];
  for (i=0; i<n; i++) fscanf(f,"%ld%ld",&d[i].x,&d[i].y);
  N=((long)n)*((long)n);
  G=new char[N]; g=new char*[n];
  for (i=0,l=0; i<n; i++,l+=(long)n) g[i]=&G[l];
  memset(G,0,N*sizeof(char));
  dd=new long[n]; de=new TEdge[n];
  for (l=0; l<m; l++) {
    fscanf(f,"%d%d",&i,&j); i--; j--;
    g[j][i]=g[i][j]=1;
  }
  o=new TEdge[n];
  h=new int[n]; q=new int[n+2];
}
void TGraph::print(FILE*f) {
  int i;
  fprintf(f,"%d\n",c);
  for (i=0; i<c; i++) fprintf(f,"%d %d\n",o[i].v+1,o[i].w+1);
}
long TGraph::dist(int v,int w) {
  long x,y,z;
  x=d[v].x-d[w].x; y=d[v].y-d[w].y;
  z=x*x+y*y;
  return(z);
}

