#include <stdio.h>

FILE*fi,*fo;

#define EPS ((long double)1e-7)

struct TPoint {
  long double x,y;
};
struct TLine {
  long double a,b,c,dx,dy;
};

class TPlane {
  private:
    int sign(long double);
    long double dist(long double,long double);
    void pp2l(TLine*,TPoint*,TPoint*);
    void lXl(TPoint*,TLine*,TLine*);
    int cmp(TPoint*,TPoint*,TPoint*);
    int cmpd(TPoint*,TPoint*,TPoint*);
    int cmp(TPoint*,TPoint*,TLine*);
    int n,m,c;
    TLine*a;
    TPoint*b,d;
    long double s;
    int*q;
    void heapifyb(int,int);
    void sortb(void);
    void addrp(int,TPoint&,TPoint&);
    void convex(void);
  public:
    TPlane(void);
    ~TPlane();
    void Delete(void);
    void scan(FILE*);
    void print(FILE*);
    void find(void);
    void evaluate(void);
};

TPlane g;

int main(void) {
  fi=fopen("convexh.in","rt");
  g.scan(fi);
  fclose(fi);
  g.find();
  g.evaluate();
  fo=fopen("convexh.out","wt");
  g.print(fo);
  fclose(fo);
  return(0);
}


void TPlane::addrp(int u,TPoint&x,TPoint&y) {
  TPoint z; long double dx,dy;
  int i,j;
  for (i=0,j=0; i<n; i++) if (i!=u) {
    lXl(&z,&a[u],&a[i]);
    if (j) {
      if (cmp(&z,&x,&a[u])<0) x=z;
      if (cmp(&z,&y,&a[u])>0) y=z;
    } else { x=z; y=z; j++; }
  }
}
void TPlane::convex(void) {
  int u,v,w,i,j;
  q[0]=v=0; c=1; if (c>=m) return;
  q[1]=w=1; c=2; if (c>=m) return;
  for (u=2; u<m; u++) if (c>2) {
    if (cmp(&b[w],&b[u],&b[v])>0) {
      q[c]=u; c++;
      v=w; w=u;
    } else {
      c--; u--;
      w=v; v=q[c-2];
    }
  } else {
    q[c]=u; c++;
    v=w; w=u;
  }
}
void TPlane::find(void) {
  int i,j;
  for (i=0,m=0; i<n; i++,m+=2) addrp(i,b[m],b[m+1]);
  d=b[0];
  for (i=1; i<m; i++) {
    if ( (b[i].y-d.y<-EPS) || ((b[i].y-d.y<EPS)&&(b[i].x-d.x<-EPS)) )
    d=b[i];
  }
  sortb();
  for (i=0,j=1; j<m; j++) {
    if (cmpd(&b[i],&b[j],&d)) i++;
    b[i]=b[j];
  } m=i+1;
  for (i=1,j=2; j<m; j++) {
    if (cmp(&b[i],&b[j],&d)) i++;
    b[i]=b[j];
  } m=i+1;
  convex();
}
void TPlane::evaluate(void) {
  int i,j,v,w;
  s=0;
  for (j=c-1,i=0; i<c; j=i++) {
    v=q[j]; w=q[i];
    s+=(b[w].y+b[v].y)*(b[v].x-b[w].x);
  }
  if (s<EPS) s=0;
  s/=2;
}

TPlane::TPlane(void) {
  a=0; b=0;
  q=0;
}
TPlane::~TPlane() {
  Delete();
}
void TPlane::Delete(void) {
  if (a) delete[]a; if (b) delete[]b;
  if (q) delete[]q;
}
void TPlane::scan(FILE*f) {
  Delete();
  int i; TPoint v,w;
  fscanf(f,"%d",&n);
  a=new TLine[n];
  for (i=0; i<n; i++) {
    fscanf(f,"%Lf%Lf%Lf%Lf",&v.x,&v.y,&w.x,&w.y);
    pp2l(&a[i],&v,&w);
  }
  b=new TPoint[n<<1];
  q=new int[(n<<1)+2];
}
void TPlane::print(FILE*f) {
  fprintf(f,"%.4Lf",s);
}
void TPlane::heapifyb(int v,int w) {
  int i,j; TPoint z;
  i=v; j=(v<<1)+1;
  if ((j<w)&&(cmpd(&b[j],&b[j+1],&d)>0)) j++;
  z=b[i];
  while ((j<=w)&&(cmpd(&z,&b[j],&d)>0)) {
    b[i]=b[j];
    i=j; j=(j<<1)+1;
    if ((j<w)&&(cmpd(&b[j],&b[j+1],&d)>0)) j++;
  }
  b[i]=z;
}
void TPlane::sortb(void) {
  int i,j; TPoint z;
  for (i=m>>1,j=m-1; i>0; i--) heapifyb(i,j);
  for (; j>0; j--) {
    heapifyb(i,j);
    z=b[i]; b[i]=b[j]; b[j]=z;
  }
}


void TPlane::pp2l(TLine*u,TPoint*v,TPoint*w) {
  u->a=v->y-w->y; u->b=w->x-v->x;
  u->c=v->x*w->y-w->x*v->y;
  u->dx=w->x-v->x; u->dy=w->y-v->y;
}
void TPlane::lXl(TPoint*u,TLine*v,TLine*w) {
  long double x,y,z;
  x=v->b*w->c-w->b*v->c;
  y=w->a*v->c-v->a*w->c;
  z=v->a*w->b-w->a*v->b;
  u->x=x/z; u->y=y/z;
}
int TPlane::cmp(TPoint*v,TPoint*w,TPoint*u) {
  long double z,x1,y1,x2,y2;
  x1=v->x-u->x; y1=v->y-u->y;
  x2=w->x-u->x; y2=w->y-u->y;
  z=x1*y2-x2*y1;
  return(sign(z));
}
int TPlane::cmpd(TPoint*v,TPoint*w,TPoint*u) {
  int z; long double x1,y1,x2,y2,d1,d2;
  x1=v->x-u->x; y1=v->y-u->y;
  x2=w->x-u->x; y2=w->y-u->y;
  z=sign(x1*y2-x2*y1);
  if (z) return(z);
  d1=dist(x1,y1); d2=dist(x2,y2);
  return(sign(d2-d1));
}
int TPlane::cmp(TPoint*v,TPoint*w,TLine*u) {
  long double V,W;
  V=v->x*u->dx+v->y*u->dy;
  W=w->x*u->dx+w->y*u->dy;
  return(sign(V-W));
}
int TPlane::sign(long double z) {
  if (z<-EPS) return(-1);
  if (z>+EPS) return(+1);
  return(0);
}
long double TPlane::dist(long double x,long double y) {
  long double z;
  z=x*x+y*y;
  return(z);
}

