#include <stdio.h>
#include <string.h>

FILE*fi,*fo;

#define INF ((long)0x7FFFFF00)

struct TEdge {
  int u;
  TEdge*z;
};
struct TPipe {
  int k,y;
  long x;
  TPipe*z;
};

class TNet {
  private:
    int n,N,m,M,c;
    long a;
    long*G,**g,*H,**h;
    TPipe*e,**D,***d;
    TEdge*B,**b;
    long*o;
    int*q,*p;
    int search(int,int);
    void enchange(int,int);
  public:
    TNet(void);
    ~TNet();
    void Delete(void);
    void scan(FILE*);
    void print(FILE*);
    void findflow(void);
    void format(void);
};

TNet g;

int main(void) {
  fi=fopen("flow.in","rt");
  g.scan(fi);
  fclose(fi);
  g.findflow();
  g.format();
  fo=fopen("flow.out","wt");
  g.print(fo);
  fclose(fo);
  return(0);
}


int TNet::search(int u,int x) {
  int i,l,v,w; TEdge*k;
  memset(p,-1,n*sizeof(int));
  q[0]=u; p[u]=u; l=1;
  for (i=0; i<l; i++) {
    v=q[i];
    for (k=b[v]; k; k=k->z) {
      w=k->u;
      if (g[v][w]<=0) continue;
      if (p[w]>=0) continue;
      q[l]=w; p[w]=v; l++;
      if (w==x) return(1);
    }
  }
  return(0);
}
void TNet::enchange(int v,int w) {
  int u;
  long z=INF;
  for (u=w; u!=v; u=p[u]) {
    if (u<0) return;
    if (g[p[u]][u]<z) z=g[p[u]][u];
  }
  for (u=w; u!=v; u=p[u]) {
    if (u<0) return;
    h[p[u]][u]+=z;
    g[p[u]][u]-=z;
    g[u][p[u]]+=z;
  }
  a+=z;
}
void TNet::findflow(void) {
  int i,j;
  for (i=0; i<n; i++) for (j=0; j<n; j++) { g[i][j]+=h[i][j]; h[i][j]=0; }
  a=0;
  while (search(0,n-1)) enchange(0,n-1);
}

TNet::TNet(void) {
  G=0; g=0;
  H=0; h=0;
  e=0; D=0; d=0;
  B=0; b=0;
  o=0;
  q=0; p=0;
}
TNet::~TNet() {
  Delete();
}
void TNet::Delete(void) {
  if (G) delete[]G; if (g) delete[]g;
  if (H) delete[]H; if (h) delete[]h;
  if (e) delete[]e; if (D) delete[]D; if (d) delete[]d;
  if (B) delete[]B; if (b) delete[]b;
  if (o) delete[]o;
  if (q) delete[]q; if (p) delete[]p;
}
void TNet::scan(FILE*f) {
  Delete();
  int i,j,v,w; long z;
  fscanf(f,"%d%d",&n,&M);
  N=n*n;
  G=new long[N]; g=new long*[n]; for (i=0,j=0; i<n; i++,j+=n) g[i]=&G[j];
  H=new long[N]; h=new long*[n]; for (i=0,j=0; i<n; i++,j+=n) h[i]=&H[j];
  e=new TPipe[M<<1];
  D=new TPipe*[N]; d=new TPipe**[n]; for (i=0,j=0; i<n; i++,j+=n) d[i]=&D[j];
  memset(G,0,N*sizeof(long)); memset(H,0,N*sizeof(long));
  memset(D,0,N*sizeof(TPipe*));
  for (m=0,i=0; i<M; i++) {
    fscanf(f,"%d%d%ld",&v,&w,&z); v--; w--;
    g[v][w]+=z;
    e[m].k=i; e[m].y=+1; e[m].x=z;
    e[m].z=d[v][w]; d[v][w]=&e[m++];
    g[w][v]+=z;
    e[m].k=i; e[m].y=-1; e[m].x=z;
    e[m].z=d[w][v]; d[w][v]=&e[m++];
  }
  B=new TEdge[N]; b=new TEdge*[n];
  for (c=0,i=0; i<n; i++) {
    b[i]=0;
    for (j=0; j<n; j++) if (g[i][j]) {
      B[c].u=j; B[c].z=b[i]; b[i]=&B[c++];
    }
  }
  o=new long[M];
  q=new int[n+2]; p=new int[n];
}
void TNet::print(FILE*f) {
  int i;
  fprintf(f,"%ld\n",a);
  for (i=0; i<M; i++) fprintf(f,"%ld\n",o[i]);
}
void TNet::format(void) {
  int i,j; TPipe*k; long z;
  memset(o,0,M*sizeof(long));
  for (i=0; i<n; i++) for (j=i+1; j<n; j++) if (h[i][j]&&h[j][i]) {
    if (h[i][j]>=h[j][i]) { h[i][j]-=h[j][i]; h[j][i]=0; }
    else { h[j][i]-=h[i][j]; h[i][j]=0; }
  }
  for (i=0; i<n; i++) for (j=0; j<n; j++) if (h[i][j]) {
    z=h[i][j];
    for (k=d[i][j]; (k)&&(z>0); k=k->z) if (o[k->k]*((long)k->y)<k->x) {
      if (z<=k->x-o[k->k]*((long)k->y)) { o[k->k]+=z*((long)k->y); z=0; }
      else { z-=k->x-o[k->k]*((long)k->y); o[k->k]=k->x*((long)k->y); }
    }
  }
}

