#include <stdio.h>

FILE*fi,*fo;

struct TPoint {
  long x,y;
};
struct TLine {
  long u,v,w;
  int operator<(TLine&);
};
class TPoly {
  private:
    long n,nx,ny,c;
    TPoint*a;
    TLine*bx,*by;
    void heapify(TLine*,long,long);
    void sort(TLine*,long);
    long find(TLine,TLine*,long);
    void count(TLine*,TLine*,long,long);
  public:
    TPoly(void);
    ~TPoly();
    void Delete(void);
    void scan(FILE*);
    void print(FILE*);
    void convert(void);
    void encount(void);
};

TPoly g;

int main(void) {
  fi=fopen("poly.in","rt");
  g.scan(fi);
  fclose(fi);
  g.convert();
  g.encount();
  fo=fopen("poly.out","wt");
  g.print(fo);
  fclose(fo);
  return(0);
}


long TPoly::find(TLine z,TLine*e,long k) {
  long u,v,w;
  for (v=0,w=k; v<w; ) {
    u=(v+w)>>1;
    if (e[u].u<=z.v) v=u+1; else if (e[u].u>=z.w) w=u;
    else if (e[u].v>=z.u) w=u;
    else if (e[u].w<=z.u) v=u+1;
    else w=u;
  }
  return(v);
}
void TPoly::count(TLine*ex,TLine*ey,long kx,long ky) {
  long i,j,l;
  for (i=0; i<kx; i++) {
    l=find(ex[i],ey,ky);
    for (j=l; (ey[j].u<ex[i].w)&&(ey[j].v<ex[i].u); j++) c++;
  }
}
void TPoly::encount(void) {
  c=0;
  if (nx<=ny) count(bx,by,nx,ny);
  else count(by,bx,ny,nx);
}

void TPoly::convert(void) {
  long i,j;
  nx=0; ny=0;
  for (j=0,i=1; i<n; j++,i++) if (a[i].x==a[j].x) {
    bx[nx].u=a[i].x;
    if (a[i].y<a[j].y) { bx[nx].v=a[i].y; bx[nx].w=a[j].y; }
    else { bx[nx].v=a[j].y; bx[nx].w=a[i].y; }
    nx++;
  } else {
    by[ny].u=a[i].y;
    if (a[i].x<a[j].x) { by[ny].v=a[i].x; by[ny].w=a[j].x; }
    else { by[ny].v=a[j].x; by[ny].w=a[i].x; }
    ny++;
  }
  sort(bx,nx);
  sort(by,ny);
}

TPoly::TPoly(void) {
  a=0;
  bx=0; by=0;
}
TPoly::~TPoly() {
  Delete();
}
void TPoly::Delete(void) {
  if (a) delete[]a;
  if (bx) delete[]bx; if (by) delete[]by;
}
void TPoly::scan(FILE*f) {
  Delete();
  long i; TPoint z;
  fscanf(f,"%ld",&n);
  a=new TPoint[n];
  for (i=0; i<n; i++) {
    fscanf(f,"%ld%ld",&z.x,&z.y);
    a[i].x=z.x+z.y;
    a[i].y=z.y-z.x;
  }
  bx=new TLine[n]; by=new TLine[n];
}
void TPoly::print(FILE*f) {
  fprintf(f,"%ld",c);
}

void TPoly::heapify(TLine*e,long v,long w) {
  long i,j; TLine z;
  i=v; j=(v<<1)+1;
  if ((j<w)&&(e[j]<e[j+1])) j++;
  z=e[i];
  while ((j<=w)&&(z<e[j])) {
    e[i]=e[j];
    i=j; j=(j<<1)+1;
    if ((j<w)&&(e[j]<e[j+1])) j++;
  }
  e[i]=z;
}
void TPoly::sort(TLine*e,long k) {
  long i,j; TLine z;
  for (i=k>>1,j=k-1; i>0; i--) heapify(e,i,j);
  for (; j>0; j--) {
    heapify(e,i,j);
    z=e[i]; e[i]=e[j]; e[j]=z;
  }
}


int TLine::operator<(TLine&b) {
  if (u<b.u) return(1); if (u>b.u) return(0);
  if (v<b.v) return(1); if (v>b.v) return(0);
  if (w<b.w) return(1); if (w>b.w) return(0);
  return(0);
}

