{$B-}
{$I+,Q+,R-,S+}
program         Template;

const
  MASK_A        = 1;
  MASK_B        = 2;
  MASK_C        = 4;
  MASK_D        = 8;

type
  TState        = record
    X, Y, A     : Byte;
    Vars        : Byte;
  end;
  TTrigger      = record
    X, Y        : Byte;
    Mask        : Byte;
  end;
  TBeacon       = record
    X, Y        : Byte;
    Expression  : string[250];
  end;

var
  M, N          : Integer;
  P, Q          : Integer;
  K             : Comp;
  X0, Y0, A0    : Integer;
  Triggers      : array[1..10000] of TTrigger;
  Beacons       : array[1..25] of TBeacon;
  States        : array[1..20000] of TState;
  StateCount    : Integer;
  X, Y, A       : Byte;
  Vars          : Byte;

procedure       OpenFiles;
begin
  Assign(Input, 'input.txt');
  Reset(Input);
  Assign(Output, 'output.txt');
  Rewrite(Output);
end;

procedure       CloseFiles;
begin
  Close(Input);
  Close(Output);
end;

procedure       ReadData;
var
  I, Code, J    : Integer;
  Ch            : Char;
  S             : string;
begin
  ReadLn(M, N, P, Q, K, X0, Y0, A0); A0 := A0 div 90;

  for I := 1 to P do begin
    Read(Triggers[I].X, Triggers[I].Y);
    Read(Ch); ReadLn(Ch);
    case UpCase(Ch) of
      'A':
        Triggers[I].Mask := MASK_A;
      'B':
        Triggers[I].Mask := MASK_B;
      'C':
        Triggers[I].Mask := MASK_C;
      'D':
        Triggers[I].Mask := MASK_D;
    end;
  end;

  for I := 1 to Q do begin
    ReadLn(S);

    Val(Copy(S, 1, Pos(' ', S) - 1), Beacons[I].X, Code);
    Delete(S, 1, Pos(' ', S));

    Val(Copy(S, 1, Pos(' ', S) - 1), Beacons[I].Y, Code);
    Delete(S, 1, Pos(' ', S));

    for J := 1 to Length(S) do
      S[J] := UpCase(S[J]);

    Beacons[I].Expression := S;
  end;
end;

procedure       RegisterState;
begin
  Inc(StateCount);

  States[StateCount].X := X;
  States[StateCount].Y := Y;
  States[StateCount].A := A;
  States[StateCount].Vars := Vars;
end;

procedure       Boom;
begin
  WriteLn('-1');
  CloseFiles;

  Halt;
end;

procedure       Move;
begin
  case A of
    0:
      Dec(Y);
    1:
      Inc(X);
    2:
      Inc(Y);
    3:
      Dec(X);
  end;

  if (X = 0) or (Y = 0) or (X > M) or (Y > N) then
    Boom;
end;

procedure       ProcessTriggers;
var
  I             : Integer;
begin
  for I := 1 to P do
    if (Triggers[I].X = X) and (Triggers[I].Y = Y) then
      Vars := Vars xor Triggers[I].Mask;
end;

function        Grep(var S: string; Sub, NewSub: string): Boolean;
var
  P             : Integer;
begin
  Grep := False;
  while Pos(Sub, S) > 0 do begin
    P := Pos(Sub, S);
    Grep := True;

    Delete(S, P, Length(Sub));
    Insert(NewSub, S, P);
  end;
end;

function        GetVar(Ch: Char): Char;
var
  RetVar        : Boolean;
begin
  case Ch of
    'A':
      RetVar := Vars and MASK_A <> 0;
    'B':
      RetVar := Vars and MASK_B <> 0;
    'C':
      RetVar := Vars and MASK_C <> 0;
    'D':
      RetVar := Vars and MASK_D <> 0;
  end;

  if RetVar then
    GetVar := '+'
  else
    GetVar := '-';
end;

function        Eval(S: string): Boolean;
var
  B             : Boolean;
begin
  S := ' ' + S + ' ';

  Grep(S, ' A ', GetVar('A'));
  Grep(S, ' B ', GetVar('B'));
  Grep(S, ' C ', GetVar('C'));
  Grep(S, ' D ', GetVar('D'));

  Grep(S, 'TRUE', '+');
  Grep(S, 'FALSE', '-');

  Grep(S, ' AND ', '&');
  Grep(S, ' OR ', '|');
  Grep(S, ' XOR ', '\');
  Grep(S, 'NOT ', '!');
  Grep(S, ' ', '');

  S := '(' + S + ')';
  repeat
    repeat
      B := False;
      B := B or Grep(S, '!+', '-');
      B := B or Grep(S, '!-', '+');

      B := B or Grep(S, '(+&+', '(+');
      B := B or Grep(S, '(+&-', '(-');
      B := B or Grep(S, '(-&+', '(-');
      B := B or Grep(S, '(-&-', '(-');
      B := B or Grep(S, '(+|+', '(+');
      B := B or Grep(S, '(+|-', '(+');
      B := B or Grep(S, '(-|+', '(+');
      B := B or Grep(S, '(-|-', '(-');
      B := B or Grep(S, '(+\+', '(-');
      B := B or Grep(S, '(+\-', '(+');
      B := B or Grep(S, '(-\+', '(+');
      B := B or Grep(S, '(-\-', '(-');
    until not B;

    B := False;
    B := B or Grep(S, '(+)', '+');
    B := B or Grep(S, '(-)', '-');
  until not B;

  if S = '+' then
    Eval := True
  else
    Eval := False;
end;

procedure       ProcessBeacons;
var
  I             : Integer;
begin
  for I := 1 to Q do
    if (Beacons[I].X = X) and (Beacons[I].Y = Y) then begin
      if Eval(Beacons[I].Expression) then
        A := (A + 1) mod 4
      else
        if A > 0 then
          A := A - 1
        else
          A := 3;
    end;
end;

procedure       CheckState;
var
  Steps, T      : Comp;
  StepsLI       : LongInt;
begin
  if (States[StateCount].X = States[1].X)
     and (States[StateCount].Y = States[1].Y)
     and (States[StateCount].A = States[1].A)
     and (States[StateCount].Vars = States[1].Vars)
     then begin
       Dec(StateCount);
       Steps := Int(K / StateCount);
       Steps := Steps * StateCount;
       Steps := K - Steps;

       StepsLI := 1 + Trunc(Steps);
       WriteLn(States[StepsLI].X, ' ', States[StepsLI].Y);

       CloseFiles;
       Halt;
     end;
end;

procedure       Solve;
begin
  StateCount := 0; X := X0; Y := Y0; A := A0; Vars := 0; RegisterState;

  repeat
    if StateCount > K then begin
      WriteLn(States[StateCount].X, ' ', States[StateCount].Y);
      CloseFiles;
      Halt;
    end;

    Move;
    ProcessTriggers;
    ProcessBeacons;
    RegisterState;
    CheckState;
  until False;
end;

begin
  OpenFiles;
  ReadData;
  Solve;
  CloseFiles;
end.
