{$I-,Q-,R-,S-}
const
  inputfile = 'tangent.in';
  outputfile = 'tangent.out';
  maxn = 101;
  eps = 1e-8;

type
  real = double;
  int = longint;
  bool = boolean;
  tpoint = record
    x, y: real;
  end;
  tline = record
    a, b, c: real;
  end;
  tcircle = record
    c: tpoint;
    r: real;
  end;

var
  i, m: int;
  c: array[1..2]of tcircle;
  t, t1, t2: tpoint;
  l: tline;

function realeq(a, b: real): bool;
begin
  realeq := abs(a - b) < eps;
end;

function realmore(a, b: real): bool;
begin
  realmore := a - b > eps;
end;

procedure norm(var l: tline);
var
  d: real;
begin
  d := sqrt(sqr(l.a) + sqr(l.b));
  if(realmore(0.0, l.a))then
    d := -d;
  l.a := l.a / d;
  l.b := l.b / d;
  l.c := l.c / d;
end;

function pointinotr(var t, tb, te: tpoint): bool;
begin
  pointinotr := false;
  if((tb.x - eps < t.x)and(t.x < te.x + eps))or((te.x - eps < t.x)and(t.x < tb.x + eps))then
    if((tb.y - eps < t.y)and(t.y < te.y + eps))or((te.y - eps < t.y)and(t.y < tb.y + eps))then
      pointinotr := true;
end;

function pointeq(var t1, t2: tpoint): bool;
begin
  pointeq := realeq(t1.x, t2.x)and realeq(t1.y, t2.y);
end;

function solvesqrur(a, b, c: real; var x1, x2: real): int;
var
  d: real;
begin
  d := sqr(b) - 4 * a * c;
  if(realmore(0.0, d))then
    solvesqrur := 0
  else begin
    d := abs(d);
    if(realmore(d, 0.0))then
      solvesqrur := 2
    else
      solvesqrur := 1;
    x1 := (-b - sqrt(d)) / (2.0 * a);
    x2 := (-b + sqrt(d)) / (2.0 * a);
  end;
end;

function crosslinecircle(var l: tline; var c: tcircle; var t1, t2: tpoint): int;
var
  ka, kb, kc: real;
  m: int;
begin
  if(not realeq(l.a, 0.0))then begin
    ka := sqr(l.b / l.a) + 1;
    kb := 2 * l.b * l.c / sqr(l.a);
    kc := sqr(l.c / l.a) - sqr(c.r);
    m := solvesqrur(ka, kb, kc, t1.y, t2.y);
    if(m > 0)then begin
      t1.x := (-l.c - l.b * t1.y) / l.a;
      t2.x := (-l.c - l.b * t2.y) / l.a;
    end;
  end else begin
    ka := sqr(l.a / l.b) + 1;
    kb := 2 * l.a * l.c / sqr(l.b);
    kc := sqr(l.c / l.b) - sqr(c.r);
    m := solvesqrur(ka, kb, kc, t1.x, t2.x);
    if(m > 0)then begin
      t1.y := (-l.c - l.b * t1.x) / l.b;
      t2.y := (-l.c - l.b * t2.x) / l.b;
    end;
  end;
  crosslinecircle := m;
end;

begin
  assign(input, inputfile);
  reset(input);
  assign(output, outputfile);
  rewrite(output);
  for i := 1 to 2 do
    read(c[i].c.x, c[i].c.y, c[i].r);
  if(pointeq(c[1].c, c[2].c))and(realeq(c[1].r, c[2].r))then
    write(-1)
  else begin
    write(0);
  end;
  close(output);
  close(input);
end.