{$I+,Q+,R+,S+}
program         Template;

const
  EPS           = 1E-8;

var
  AX, AY        : Extended;
  BX, BY        : Extended;
  CX, CY        : Extended;
  DX, DY        : Extended;

procedure       OpenFiles;
begin
  Assign(Input, 'segment.in');
  Reset(Input);
  Assign(Output, 'segment.out');
  Rewrite(Output);
end;

procedure       CloseFiles;
begin
  Close(Input);
  Close(Output);
end;

procedure       ReadData;
begin
  Read(AX, AY, BX, BY, CX, CY, DX, DY);
end;

function        FEq(A, B: Extended): Boolean;
begin
  FEq := Abs(A - B) <= EPS;
end;

function        IsEmpty(X1, Y1, X2, Y2: Extended): Boolean;
begin
  IsEmpty := FEq(X1, X2) and FEq(Y1, Y2);
end;

function        Min(A, B: Extended): Extended;
begin
  if A < B then
    Min := A
  else
    Min := B;
end;

function        Max(A, B: Extended): Extended;
begin
  if A > B then
    Max := A
  else
    Max := B;
end;

function        IsInside(X, Y, X1, Y1, X2, Y2: Extended): Boolean;
begin
  IsInside := (X >= Min(X1, X2)) and
              (X <= Max(X1, X2)) and
              (Y >= Min(Y1, Y2)) and
              (Y <= Max(Y1, Y2));
end;

procedure       ReturnEmpty;
begin
  WriteLn('Empty');

  CloseFiles;
  Halt;
end;

procedure       ReturnPoint(X, Y: Extended);
begin
  WriteLn(X:0:6, ' ', Y:0:6);

  CloseFiles;
  Halt;
end;

procedure       Normalize(var A, B, C: Extended);
var
  D             : Extended;
begin
  if A < 0 then begin
    A := -A;
    B := -B;
    C := -C;
  end;

  D := Sqrt(A * A + B * B);

  if D <> 0 then begin
    A := A / D;
    B := B / D;
    C := C / D;
  end;
end;

procedure       ReturnSegment(X1, Y1, X2, Y2: Extended);
begin
  WriteLn(X1:0:6, ' ', Y1:0:6, ' ', X2:0:6, ' ', Y2:0:6);

  CloseFiles;
  Halt;
end;

procedure       Solve;
var
  A1, B1, C1    : Extended;
  A2, B2, C2    : Extended;
  K, Q, X, Y    : Extended;
  X1, Y1, X2, Y2: Extended;
begin
  A1 := AY - BY;                A2 := CY - DY;
  B1 := BX - AX;                B2 := DX - CX;
  C1 := -A1 * AX - B1 * AY;     C2 := -A2 * CX - B2 * CY;
  Normalize(A1, B1, C1);        Normalize(A2, B2, C2);

  if IsEmpty(AX, AY, BX, BY) then begin         { 1. १ AB ஦ }
    if IsEmpty(CX, CY, DX, DY) then begin       {    a) CD ஦         }
      if FEq(AX, CX) and FEq(AY, CY) then       {       - 窨 ᮢ   }
        ReturnPoint(AX, AY)
      else
        ReturnEmpty;                            {       - 窨 ࠧ   }
    end else begin                              {    b) CD  ஦      }
      if FEq(A2 * AX + B2 * AY + C2, 0) then begin {    - 窠  אַ   }
        if IsInside(AX, AY, CX, CY, DX, DY) then
          ReturnPoint(AX, AY)
        else
          ReturnEmpty;
      end else
        ReturnEmpty;                            {       - 窠  १ }
    end;
  end;

  if IsEmpty(CX, CY, DX, DY) then begin         { 1. १ AB ஦ }
    if IsEmpty(AX, AY, BX, BY) then begin       {    a) CD ஦         }
      if FEq(AX, CX) and FEq(AY, CY) then       {       - 窨 ᮢ   }
        ReturnPoint(CX, CY)
      else
        ReturnEmpty;                            {       - 窨 ࠧ   }
    end else begin                              {    b) CD  ஦      }
      if FEq(A1 * CX + B1 * CY + C2, 0) then begin {    - 窠  אַ   }
        if IsInside(CX, CY, AX, AY, BX, BY) then
          ReturnPoint(CX, CY)
        else
          ReturnEmpty;
      end else
        ReturnEmpty;                            {       - 窠  १ }
    end;
  end;

  if FEq(A1, A2) and FEq(B1, B2) then begin
    if C1 <> C2 then
      ReturnEmpty
    else begin
      if Max(AX, BX) >= Min(CX, DX) then begin {****}
        X1 := Max(AX, BX); X2 := Min(CX, DX);
        if B1 = 0 then begin
          if X1 = X2 then
            ReturnSegment(X1, Max(AY, BY), X2, Min(CY, DY))
          else
            ReturnEmpty;
        end else begin
          Y1 := (-C1 - A1 * X1) / B1;
          Y2 := (-C2 - A2 * X2) / B2;
          if not FEq(Y1, Y2) or not FEq(X1, X2) then
            ReturnSegment(X1, Y1, X2, Y2)
          else
            ReturnPoint(X1, Y1);
        end;
      end;
      if Max(CX, DX) >= Min(AX, BX) then begin
        X1 := Max(CX, DX); X2 := Min(AX, BX);
        if B1 = 0 then begin
          if X1 = X2 then
            ReturnSegment(X1, Max(CY, DY), X2, Min(AY, BY))
          else
            ReturnEmpty;
        end else begin
          Y2 := (-C1 - A1 * X2) / B1;
          Y1 := (-C2 - A2 * X1) / B2;

          ReturnSegment(X1, Y1, X2, Y2);
        end;
      end;
    end;
    Exit;
  end;

  if B1 <> 0 then begin
    K := B2 * A1 / B1 - A2;
    Q := C2 + B2 * C1 / B1;
    X := Q / K;
    Y := (C1 - A1 * X) / B1;
    if IsInside(X, Y, AX, AY, BX, BY) and IsInside(X, Y, CX, CY, DX, DY) then
      ReturnPoint(X, Y)
    else
      ReturnEmpty;
  end else begin
    K := B1 * A2 / B2 - A1;
    Q := C1 + B1 * C2 / B2;
    X := Q / K;
    Y := (C2 - A2 * X) / B2;
    if IsInside(X, Y, AX, AY, BX, BY) and IsInside(X, Y, CX, CY, DX, DY) then
      ReturnPoint(X, Y)
    else
      ReturnEmpty;
  end;
end;

begin
  OpenFiles;
  ReadData;
  Solve;
  CloseFiles;
end.
