const
     FileIn='segment.in';
     FileOut='segment.out';
     ansEmpty=0;
     ansPoint=1;
     ansRange=2;
     Eps=1e-7;
type
    TPoint=record
                 X, Y: Extended;
           end;
    TLine=record
                A, B, C, X1, Y1, X2, Y2: Extended;
          end;
var
   Line1, Line2: TLine;
   AnswerType: Byte;
   Point1, Point2: TPoint;

procedure ReadData;
var
   F: Text;
begin
     Assign (F, FileIn);
     Reset (F);
     Readln (F, Line1.X1, Line1.Y1, Line1.X2, Line1.Y2, Line2.X1, Line2.Y1, Line2.X2, Line2.Y2);
     Close (F);
end;

procedure WriteData;
var
   F: Text;
begin
     Assign (F, FileOut);
     Rewrite (F);
     case AnswerType of
          ansEmpty: Writeln (F, 'Empty');
          ansPoint: Writeln (F, Point1.X:0:6, #32, Point1.Y:0:6);
          ansRange: Writeln (F, Point1.X:0:6, #32, Point1.Y:0:6, #32, Point2.X:0:6, #32, Point2.Y:0:6);
     end;
     Close (F);
end;

procedure IntersectionPoint (aLine1, aLine2: TLine; var aPoint: TPoint; var aIntersects: Boolean);
var
   A1, A2, B1, B2, C1, C2: Extended;
begin
     A1:=aLine1.A;
     B1:=aLine1.B;
     C1:=aLine1.C;
     A2:=aLine2.A;
     B2:=aLine2.B;
     C2:=aLine2.C;
     aIntersects:=true;
     if (Abs (A2*aLine1.X1+B2*aLine1.Y1+C1)<Eps) and (Abs (aLine1.X1-aLine1.X2)<Eps) and (Abs (aLine1.Y1-aLine1.Y2)<Eps)
        then begin
             aPoint.X:=aLine1.X1;
             aPoint.Y:=aLine1.Y1;
        end
        else if (Abs (A1*aLine2.X1+B1*aLine2.Y1+C2)<Eps) and (Abs (aLine2.X1-aLine2.X2)<Eps) and (Abs (aLine2.Y1-aLine2.Y2)<Eps)
                then begin
                     aPoint.X:=aLine2.X1;
                     aPoint.Y:=aLine2.Y1;
                end
                else if (Abs (B1)>=Eps) and (Abs (B2/B1*A1-A2)>=Eps)
                        then begin
                             aPoint.X:=(B2/B1*C1+C2)/(B2/B1*A1-A2);
                             aPoint.Y:=-(C1+A1*aPoint.X)/B1
                        end
                        else begin
                             aPoint.X:=0;
                             aPoint.Y:=0;
                             aIntersects:=false;
                        end;
end;

function Min (aA, aB: Extended): Extended;
begin
     if aA<aB
        then Min:=aA
        else Min:=aB;
end;

function Max (aA, aB: Extended): Extended;
begin
     if aA<aB
        then Max:=aB
        else Max:=aA;
end;

function CanTheyIntersectAt (aLine1, aLine2: TLine; aPoint: TPoint): Boolean;
begin
     CanTheyIntersectAt:=(aPoint.X<Max (aLine1.X1, aLine1.X2)+Eps) and
                         (aPoint.X+Eps>Min (aLine1.X1, aLine1.X2)) and
                         (aPoint.Y<Max (aLine1.Y1, aLine1.Y2)+Eps) and
                         (aPoint.Y+Eps>Min (aLine1.Y1, aLine1.Y2)) and
                         (aPoint.X<Max (aLine2.X1, aLine2.X2)+Eps) and
                         (aPoint.X+Eps>Min (aLine2.X1, aLine2.X2)) and
                         (aPoint.Y<Max (aLine2.Y1, aLine2.Y2)+Eps) and
                         (aPoint.Y+Eps>Min (aLine2.Y1, aLine2.Y2));
end;

procedure GenerateLine (var aLine: TLine);
begin
     aLine.A:=aLine.Y2-aLine.Y1;
     aLine.B:=aLine.X1-aLine.X2;
     aLine.C:=-(aLine.A*aLine.X1+aLine.B*aLine.Y1);
end;

procedure Swap (var aA, aB: Extended);
var
   T: Extended;
begin
     T:=aA;
     aA:=aB;
     aB:=T;
end;

function IntersectProjections (aSeg1, aSeg2: TPoint; var aRes: TPoint): Boolean;
begin
     IntersectProjections:=true;
     if aSeg1.Y<aSeg1.X
        then Swap (aSeg1.Y, aSeg1.X);
     if aSeg2.Y<aSeg2.X
        then Swap (aSeg2.Y, aSeg2.X);
     if (aSeg1.X<aSeg2.X+Eps) and (aSeg1.Y+Eps>aSeg2.X) and (aSeg1.Y<aSeg2.Y+Eps)
        then begin
             aRes.X:=aSeg2.X;
             aRes.Y:=aSeg1.Y;
        end
        else if (aSeg1.X+Eps>aSeg2.X) and (aSeg1.Y<aSeg2.Y+Eps)
                then begin
                     aRes.X:=aSeg1.X;
                     aRes.Y:=aSeg1.Y;
                end
                else if (aSeg1.X<aSeg2.X+Eps) and (aSeg1.Y+Eps>aSeg2.Y)
                        then begin
                             aRes.X:=aSeg2.X;
                             aRes.Y:=aSeg2.Y;
                        end
                        else if (aSeg2.X<aSeg1.X) and (aSeg2.Y+Eps>aSeg1.X) and (aSeg2.X<aSeg1.Y+Eps)
                                then begin
                                     aRes.X:=aSeg1.X;
                                     aRes.Y:=aSeg2.Y;
                                end
                                else IntersectProjections:=false;

end;

procedure SolveParallel;
var
   k: Extended;
   Seg1, Seg2, Pnt: TPoint;
begin
     if Abs (Line2.A)>Eps
        then k:=Line1.A/Line2.A
        else if Abs (Line2.B)>Eps
                then k:=Line1.B/Line2.B
                else if Abs (Line2.C)>Eps
                        then k:=Line1.C/Line2.C
                        else begin
                             AnswerType:=ansEmpty;
                             Exit;
                        end;
     if ((Line1.A-Line2.A*K)>Eps) or
        ((Line1.B-Line2.B*K)>Eps) or
        ((Line1.C-Line2.C*K)>Eps)
        then AnswerType:=ansEmpty
        else begin
             Seg1.X:=Line1.X1;
             Seg1.Y:=Line1.X2;
             Seg2.X:=Line2.X1;
             Seg2.Y:=Line2.X2;
             case IntersectProjections (Seg1, Seg2, Pnt) of
                  false: AnswerType:=ansEmpty;
                  true: begin
                             Point1.X:=Pnt.X;
                             Point2.X:=Pnt.Y;

                             Seg1.X:=Line1.Y1;
                             Seg1.Y:=Line1.Y2;
                             Seg2.X:=Line2.Y1;
                             Seg2.Y:=Line2.Y2;
                             case IntersectProjections (Seg1, Seg2, Pnt) of
                                  false: AnswerType:=ansEmpty;
                                  true: begin
                                             Point1.Y:=Pnt.X;
                                             Point2.Y:=Pnt.Y;
                                             AnswerType:=ansRange;
                                        end;
                             end;
                        end;
             end;
        end;
end;

procedure Solve;
var
   Intersect: Boolean;
begin
     GenerateLine (Line1);
     GenerateLine (Line2);
     IntersectionPoint (Line1, Line2, Point1, Intersect);
     case Intersect of
          false: SolveParallel;
          true: begin
                     Intersect:=CanTheyIntersectAt (Line1, Line2, Point1);
                     case Intersect of
                          false: AnswerType:=ansEmpty;
                          true: AnswerType:=ansPoint;
                     end;
                end;
     end;
end;

procedure Main;
begin
     ReadData;
     Solve;
     WriteData;
end;

begin
     Main;
end.
