{$I+,Q-,R-,S+}
program         Template;

type
  TSegment      = record
    X1, Y1      : Integer;
    X2, Y2      : Integer;
  end;

  TCoord        = record
    X, Y        : Integer;
  end;

  PVertex       = ^TVertex;
  TVertex       = record
    Y, U        : Integer;
    Next        : PVertex;
  end;

  PEdge         = ^TEdge;
  TEdge         = record
    A, B        : Integer;
    Next        : PEdge;
  end;

  TNeighborhood = set of 1..5;

var
  N, V          : Integer;
  Segments      : array[1..5000] of TSegment;
  Vertices      : array[-10000..10000] of PVertex;
  Coords        : array[1..10000] of TCoord;
  Power         : array[1..10000] of Integer;
  Edges         : array[1..10000] of PEdge;
  Count         : Integer;
  Colors        : array[1..10000] of Integer;

procedure       OpenFiles;
begin
  Assign(Input, 'input.txt');
  Reset(Input);
  Assign(Output, 'output.txt');
  Rewrite(Output);
end;

procedure       CloseFiles;
begin
  Close(Input);
  Close(Output);
end;

procedure       ReadData;
var
  I             : Integer;
begin
  ReadLn(N);
  for I := 1 to N do
    ReadLn(Segments[I].X1, Segments[I].Y1, Segments[I].X2, Segments[I].Y2);
end;

(* ஥  *********************************************************)

function        FindPoint(X, Y: Integer): Integer;
var
  Vert          : PVertex;
begin
  Vert := Vertices[X];
  while Vert^.Y <> Y do
    Vert := Vert^.Next;

  FindPoint := Vert^.U;
end;

procedure       AddPoint(X, Y: Integer);
var
  Vert, NewVert : PVertex;
  LastVert      : PVertex;
begin
  if Vertices[X] <> nil then begin
    Vert := Vertices[X]; LastVert := nil;
    while (Vert <> nil) and (Vert^.Y < Y) do begin
      LastVert := Vert;
      Vert := Vert^.Next;
    end;

    if Vert = nil then begin
      Inc(V);

      New(NewVert);
      NewVert^.Y := Y;
      NewVert^.U := V;
      NewVert^.Next := nil;

      LastVert^.Next := NewVert;

      Coords[V].X := X;
      Coords[V].Y := Y;
    end else if Vert^.Y > Y then begin
      Inc(V);

      New(NewVert);
      NewVert^.Y := Y;
      NewVert^.U := V;
      NewVert^.Next := Vert;

      if LastVert <> nil then
        LastVert^.Next := NewVert
      else
        Vertices[X] := NewVert;

      Coords[V].X := X;
      Coords[V].Y := Y;
    end;
  end else begin
    Inc(V);

    New(Vertices[X]);
    Vertices[X]^.Y := Y;
    Vertices[X]^.U := V;
    Vertices[X]^.Next := nil;

    Coords[V].X := X;
    Coords[V].Y := Y;
  end;
end;

procedure       AddFence(X1, Y1, X2, Y2: Integer);
var
  V1, V2        : Integer;
  Edge          : PEdge;
begin
  V1 := FindPoint(X1, Y1); Inc(Power[V1]);
  V2 := FindPoint(X2, Y2); Inc(Power[V2]);

  New(Edge);
  Edge^.A := V1;
  Edge^.B := V2;
  Edge^.Next := Edges[V1];
  Edges[V1] := Edge;

  New(Edge);
  Edge^.A := V2;
  Edge^.B := V1;
  Edge^.Next := Edges[V2];
  Edges[V2] := Edge;
end;

procedure       BuildGraph;
var
  I             : Integer;
begin
  V := 0; FillChar(Vertices, SizeOf(Vertices), 0);
  for I := 1 to N do begin
    AddPoint(Segments[I].X1, Segments[I].Y1);
    AddPoint(Segments[I].X2, Segments[I].Y2);
  end;

  FillChar(Power, SizeOf(Power), 0); FillChar(Edges, SizeOf(Edges), 0);
  for I := 1 to N do
    AddFence(Segments[I].X1, Segments[I].Y1, Segments[I].X2, Segments[I].Y2);
end;

(*   㡨 **********************************************************)

procedure       DFS(U: Integer);
var
  E             : PEdge;
  I             : Integer;
  Hood          : TNeighborhood;
begin
  Inc(Count);

  Hood := []; E := Edges[U];
  while E <> nil do begin
    if Colors[E^.B] <> 0 then
      Include(Hood, Colors[E^.B]);

    E := E^.Next;
  end;

  for I := 1 to 5 do
    if not (I in Hood) then begin
      Colors[U] := I;
      Break;
    end;

  E := Edges[U];
  while E <> nil do begin
    if Colors[E^.B] = 0 then
      DFS(E^.B);

    E := E^.Next;
  end;
end;

procedure       Solve;
var
  I             : Integer;
begin
  BuildGraph;

  Count := 0; FillChar(Colors, SizeOf(Colors), 0);
  while Count < V do begin
    I := 1;
    while (Colors[I] > 0) and (I < V) do
      Inc(I);

    DFS(I);
  end;

  for I := 1 to V do
    WriteLn(Coords[I].X, ' ', Coords[I].Y, ' ', Colors[I]);
end;

begin
  OpenFiles;
  ReadData;
  Solve;
  CloseFiles;
end.
