{$I-,Q-,R-,S-}
const
     FileIn='input.txt';
     FileOut='output.txt';
     MaxN=5000;
     MaxNodes=MaxN*2;
     MaxSquares=MaxN;
     stUnvisited=0;
     stUnderProcessing=1;
     stProcessed=2;
     stWasFirst=3;
     Eps=1e-7;
type
    PNodeIndex=^TNodeIndex;
    TNodeIndex=record
                     Index: Integer;
                     Next: PNodeIndex;
               end;
    TNode=record
                X, Y: Integer;
                Next: PNodeIndex;
                State: Byte;
                Brightness: LongInt;
          end;
    TSquare=record
                  S: Extended;
                  Next: PNodeIndex;
            end;
var
   N, NodesCount: LongInt;
   Nodes: array [1..MaxNodes] of TNode;
   LastPointers: array [1..MaxNodes] of PNodeIndex;
   Answer: LongInt;
   Stack: array [1..MaxNodes] of Integer;
   StackLen: LongInt;
   Squares: array [1..MaxSquares] of TSquare;

function XYToNNode (aX, aY: Integer): LongInt;
var
   NNode: LongInt;
begin
     for NNode:=1 to NodesCount
         do if (Nodes [NNode].X=aX) and (Nodes [NNode].Y=aY)
               then begin
                    XYToNNode:=NNode;
                    Exit;
               end;
     Inc (NodesCount);
     Nodes [NodesCount].X:=aX;
     Nodes [NodesCount].Y:=aY;
     Nodes [NodesCount].Next:=nil;
     Nodes [NodesCount].State:=stUnvisited;
     Nodes [NodesCount].Brightness:=0;
     LastPointers [NodesCount]:=nil;
     XYToNNode:=NodesCount;
end;

procedure AddNeighbor (aNode, aNeNode: Integer);
begin
     if LastPointers [aNode]=nil
        then begin
             Nodes [aNode].Next:=New (PNodeIndex);
             Nodes [aNode].Next^.Index:=aNeNode;
             LastPointers [aNode]:=Nodes [aNode].Next;
        end
        else begin
             LastPointers [aNode]^.Next:=New (PNodeIndex);
             LastPointers [aNode]:=LastPointers [aNode]^.Next;
             LastPointers [aNode]^.Index:=aNeNode;
        end;
     LastPointers [aNode]^.Next:=nil;
end;

procedure ReadData;
var
   F: Text;
   NEdge: LongInt;
   X1, Y1, X2, Y2: Integer;
   Node1, Node2: Integer;
begin
     FillChar (LastPointers, SizeOf (LastPointers), 0);
     Assign (F, FileIn);
     Reset (F);
     Readln (F, N);
     for NEdge:=1 to N
         do begin
            Readln (F, X1, Y1, X2, Y2);
            Node1:=XYToNNode (X1, Y1);
            Node2:=XYToNNode (X2, Y2);
            AddNeighbor (Node1, Node2);
            AddNeighbor (Node2, Node1);
         end;
     Close (F);
end;

procedure WriteData;
var
   F: Text;
   NSquare: LongInt;
begin
     Assign (F, FileOut);
     Rewrite (F);
     Writeln (F, Answer);
     for NSquare:=1 to Answer
         do Writeln (F, Squares [NSquare].S:0:5);
     Close (F);
end;

procedure CalcNewSquare (aFirstStackPoint: LongInt);
var
   NItem: LongInt;
begin
     Inc (Answer);
     Squares [Answer].S:=0;
     for NItem:=aFirstStackPoint to StackLen-1
         do Squares [Answer].S:=Squares [Answer].S+Nodes [Stack [NItem]].X*Nodes [Stack [NItem+1]].Y-Nodes [Stack [NItem+1]].X*Nodes [Stack [NItem]].Y;
     Squares [Answer].S:=Abs (Squares [Answer].S/2);
     Squares [Answer].Next:=New (PNodeIndex);
     Squares [Answer].Next^.Index:=Stack [aFirstStackPoint];
end;

procedure StoreSqStack (aFirstStackPoint: LongInt);
var
   NItem: LongInt;
   Curr: PNodeIndex;
begin
     Curr:=Squares [Answer].Next;
     for NItem:=aFirstStackPoint to StackLen-1
         do begin
            Curr^.Next:=New (PNodeIndex);
            Curr:=Curr^.Next;
            Curr^.Index:=Stack [NItem];
         end;
     Curr^.Next:=nil;
end;

function LastSquareIsDuplicate (aFirstStackPoint: LongInt): Boolean;
var
   Used: array [1..MaxNodes] of Boolean;
   NSquare, NItem: Longint;
   Bad: Boolean;
   Curr: PNodeIndex;
begin
     for NSquare:=1 to Answer-1
         do if Abs (Squares [NSquare].S-Squares [Answer].S)<Eps
               then begin
                    FillChar (Used, SizeOf (Used), 0);
                    Curr:=Squares [NSquare].Next;
                    while Assigned (Curr)
                        do begin
                           Used [Curr^.Index]:=true;
                           Curr:=Curr^.Next;
                        end;
                    Bad:=true;
                    for NItem:=aFirstStackPoint to StackLen-1
                        do if not Used [Stack [NItem]]
                              then begin
                                   Bad:=false;
                                   Break;
                              end;
                    if Bad
                       then begin
                            LastSquareIsDuplicate:=true;
                            Exit;
                       end;
               end;
     LastSquareIsDuplicate:=false;
end;

procedure WorkWithRegion;
var
   NStackNode: LongInt;
begin
     for NStackNode:=StackLen-1 downto 1
         do if Stack [NStackNode]=Stack [StackLen]
               then begin
                    for NStackNode:=StackLen-1 downto NStackNode
                        do if Nodes [Stack [NStackNode]].Brightness>2
                              then Exit;
                    CalcNewSquare (NStackNode);
                    if LastSquareIsDuplicate (NStackNode)
                       then Dec (Answer)
                       else StoreSqStack (NStackNode);
                    Break;
               end;
end;

procedure DFSVisit;
var
   CurNeIndex: PNodeIndex;
begin
     Nodes [Stack [StackLen]].State:=stUnderProcessing;
     CurNeIndex:=Nodes [Stack [StackLen]].Next;
     while Assigned (CurNeIndex)
           do begin
              Inc (Nodes [CurNeIndex^.Index].Brightness);
              CurNeIndex:=CurNeIndex^.Next;
           end;
     CurNeIndex:=Nodes [Stack [StackLen]].Next;
     while Assigned (CurNeIndex)
           do begin
              case Nodes [CurNeIndex^.Index].State of
                   stUnvisited,
                   stProcessed: begin
                                   Inc (StackLen);
                                   Stack [StackLen]:=CurNeIndex^.Index;
                                   DFSVisit;
                                   Dec (StackLen);
                              end;
                   stUnderProcessing: if Stack [StackLen-1]<>CurNeIndex^.Index
                                         then begin
                                              Inc (StackLen);
                                              Stack [StackLen]:=CurNeIndex^.Index;
                                              WorkWithRegion;
                                              Dec (StackLen);
                                         end;
              end;
              CurNeIndex:=CurNeIndex^.Next;
           end;
     CurNeIndex:=Nodes [Stack [StackLen]].Next;
     while Assigned (CurNeIndex)
           do begin
              Dec (Nodes [CurNeIndex^.Index].Brightness);
              CurNeIndex:=CurNeIndex^.Next;
           end;
     Nodes [Stack [StackLen]].State:=stProcessed;
end;

procedure Solve;
var
   NNode: LongInt;
begin
     Answer:=0;
     StackLen:=1;
     for NNode:=1 to NodesCount
         do if Nodes [NNode].State<>stWasFirst
               then begin
                    Stack [StackLen]:=NNode;
                    DFSVisit;
                    Nodes [NNode].State:=stWasFirst;
               end;
end;

procedure Main;
begin
     ReadData;
     Solve;
     WriteData;
end;

begin
     Main;
end.
