{$I+,Q-,R-,S+}
program         Template;

const
  SPADES        = 1;
  HEARTS        = 2;
  DIAMONDS      = 3;
  CROSSES       = 4;

  ACE           = 1;
  TWO           = 2;
  THREE         = 3;
  FOUR          = 4;
  FIVE          = 5;
  SIX           = 6;
  SEVEN         = 7;
  EIGHT         = 8;
  NINE          = 9;
  TEN           = 10;
  JACK          = 11;
  QUEEN         = 12;
  KING          = 13;

  NORTH         = 1;
  SOUTH         = 2;
  EAST          = 3;
  WEST          = 4;
  TOTAL         = 5;

  TOK_COUNT     = 1;
  TOK_CARD      = 2;
  TOK_OR        = 3;
  TOK_AND       = 4;
  TOK_OPEN      = 5;
  TOK_CLOSE     = 6;

type
  TToken        = record
    Kind        : Integer;
    Player      : Integer;
    C1, C2      : Integer;
    Count       : Integer;
  end;

var
  Cards, NCards : array[1..4, 1..13] of Byte;
  SCards        : array[1..4, 1..13] of Byte;
  Counts, NCnts : array[1..5, 1..4] of Integer;
  SCnts         : array[1..5, 1..4] of Integer;
  Expr          : string;
  Evaluated     : array[1..80] of Boolean;

procedure       OpenFiles;
begin
  Assign(Input, 'bridge.in');
  Reset(Input);
  Assign(Output, 'bridge.out');
  Rewrite(Output);
end;

procedure       CloseFiles;
begin
  Close(Input);
  Close(Output);
end;

procedure       Convert(ID: string; var AN, BN: Integer);
var
  A, B          : Char;
begin
  A := ID[2];
  B := ID[1];

  case A of
    's':
      AN := SPADES;
    'h':
      AN := HEARTS;
    'd':
      AN := DIAMONDS;
    'c':
      AN := CROSSES;
  end;

  case B of
    'A':
      BN := ACE;
    '2'..'9':
      BN := Ord(B) - 48;
    'T':
      BN := TEN;
    'J':
      BN := JACK;
    'Q':
      BN := QUEEN;
    'K':
      BN := KING;
  end;
end;

procedure       BuildList(Player: Integer; Src: string);
var
  I             : Integer;
  AN, BN        : Integer;
begin
  for I := 1 to 13 do begin
    Convert(Copy(Src, I * 2 - 1, 2), AN, BN);

    Cards[AN, BN] := Player;

    Inc(Counts[Player, AN]);
    Inc(Counts[TOTAL, AN]);
  end;
end;

procedure       ReadData;
var
  Str           : string;
begin
  FillChar(Cards, SizeOf(Cards), 0);
  FillChar(Counts, SizeOf(Counts), 0);

  ReadLn(Str); BuildList(NORTH, Str);
  ReadLn(Str); BuildList(SOUTH, Str);
  ReadLn(Expr);
end;

function        NextToken(var Pos: Integer; var Token: TToken): Boolean;
var
  S             : string;
begin
  NextToken := True;
  if Pos > Length(Expr) then begin
    NextToken := False;
    Exit;
  end;

  FillChar(Token, SizeOf(Token), 0);
  case Expr[Pos] of
    '(': begin
      Token.Kind := TOK_OPEN;
      Inc(Pos);
      Exit;
    end;
    ')': begin
      Token.Kind := TOK_CLOSE;
      Inc(Pos);
      Exit;
    end;
    '&': begin
      Token.Kind := TOK_AND;
      Inc(Pos);
      Exit;
    end;
    '|': begin
      Token.Kind := TOK_OR;
      Inc(Pos);
      Exit;
    end;
  end;

  if Expr[Pos] in ['s', 'h', 'c', 'd'] then begin
    Token.Kind := TOK_COUNT;
    case Expr[Pos] of
      's':
        Token.C1 := SPADES;
      'h':
        Token.C1 := HEARTS;
      'd':
        Token.C1 := DIAMONDS;
      'c':
        Token.C1 := CROSSES;
    end;

    Inc(Pos, 2);
    case Expr[Pos] of
      'W':
        Token.Player := WEST;
      'E':
        Token.Player := EAST;
    end;

    Inc(Pos, 2); S := '';
    repeat
      S := S + Expr[Pos];
      Inc(Pos);
    until (Pos > Length(S)) or not (Expr[Pos] in ['0'..'9']);

    Val(S, Token.Count);
    Exit;
  end;

  Token.Kind := TOK_CARD;

  S := Copy(Expr, Pos, 2);
  Convert(S, Token.C1, Token.C2);

  Inc(Pos, 3);
  case Expr[Pos] of
    'W':
      Token.Player := WEST;
    'E':
      Token.Player := EAST;
  end;

  Inc(Pos);
end;

function        CountVariants: Int64;
var
  I, J          : Integer;
begin
  CountVariants := 1;
end;

procedure       Parse(var Pos: Integer; var Count: Int64);
var
  Token         : TToken;
  Proceed       : Boolean;
  OP            : Integer;
begin
  Move(Cards, NCards, SizeOf(Cards));
  Move(Counts, NCnts, SizeOf(NCnts));

  if not NextToken(Pos, Token) or (Token.Kind = TOK_CLOSE) then begin
    Count := Count + CountVariants;
    Exit;
  end;

  Proceed := True;
  case Token.Kind of
    TOK_CARD: begin
      if (Cards[Token.C1, Token.C2] = 0) or (Cards[Token.C1, Token.C2] = Token.Player) then
        NCards[Token.C1, Token.C2] := Token.Player
      else begin
        Proceed := False;
        Count := 0;
      end;
    end;
    TOK_COUNT: begin
      if (Counts[Token.Player, Token.C1] = 0) or (Counts[Token.Player, Token.C1] = Token.Count) then begin
        if Counts[Token.Player, Token.C1] = 0 then
          Inc(NCnts[TOTAL, Token.C1], Token.Count);

        NCnts[Token.Player, Token.C1] := Token.Count;
      end else begin
        Proceed := False;
        Count := 0;
      end;
    end;
    TOK_OPEN:
      Parse(Pos, Count);
  end;

  if not Proceed then
    Exit;

  if not NextToken(Pos, Token) or (Token.Kind = TOK_CLOSE) then begin
    Count := Count + CountVariants;
    Exit;
  end;

  case Token.Kind of
    TOK_AND: begin
      Move(Cards, SCards, SizeOf(Cards));
      Move(Counts, SCnts, SizeOf(SCnts));
      Move(NCards, Cards, SizeOf(Cards));
      Move(NCnts, Counts, SizeOf(NCnts));

      Parse(Pos, Count);

      Move(SCards, Cards, SizeOf(Cards));
      Move(SCnts, Counts, SizeOf(SCnts));
    end;
    TOK_OR: begin
      Move(Cards, SCards, SizeOf(Cards));
      Move(Counts, SCnts, SizeOf(SCnts));
      Move(NCards, Cards, SizeOf(Cards));
      Move(NCnts, Counts, SizeOf(NCnts));

      OP := Pos; Parse(Pos, Count); Pos := OP;

      Move(SCards, Cards, SizeOf(Cards));
      Move(SCnts, Counts, SizeOf(SCnts));

      Parse(Pos, Count);
    end;
  end;

  Move(NCards, Cards, SizeOf(Cards));
  Move(NCnts, Counts, SizeOf(NCnts));
end;

procedure       Solve;
var
  Pos           : Integer;
  Count         : Int64;
begin
  FillChar(Evaluated, SizeOf(Evaluated), 0);

  Pos := 1; Count := 0; Parse(Pos, Count);

  if Count = 0 then
    WriteLn(10400600)
  else
    WriteLn(0);
end;

begin
  OpenFiles;
  ReadData;
  Solve;
  CloseFiles;
end.
